C$Procedure      ADDLNK ( Add a new AB cell to the linked list )
 
      SUBROUTINE ADDLNK ( AVAL, BVAL, MAXVAL, PNTRS, NCELL, CELLS )
      IMPLICIT NONE

C$ Abstract
C
C     Open and add a new AB cell to the linked-list and
C     update the A-value pointer array.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     AB linked list
C
C$ Declarations
 
      INCLUDE               'pltmax.inc'

      INTEGER               AVAL
      INTEGER               BVAL
      INTEGER               MAXVAL
      INTEGER               PNTRS  ( * )
      INTEGER               NCELL
      INTEGER               CELLS  ( 2, * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVAL       I   A-value to put in new cell.
C     BVAL       I   B-value to put in new cell.
C     PNTRS     I/O  A-value pointer array to update.
C     NCELL     I/O  Number of cells in AB cell linked-list.
C     CELL      I/O  Cell array.
C
C$ Detailed_Input
C
C     AVAL       A-value to be placed in new cell.
C
C     BVAL       Associated B-value to be placed in new cell.
C
C     PNTRS      Pointers to last cell containing a given A-value.
C                Updated on output.
C
C     NCELL      Number of cells, incremented by one on output.
C
C     CELL       Cell array, updated on output.
C
C$ Detailed_Output
C
C     PNTRS      See Detailed_Input.
C
C     NCELL      See Detailed_Input.
C
C     CELL       See Detailed_Input.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the array index AVAL exceeds the decalared 
C        size of the PNTR array, the error SPICE(ARRAYTOOSMALL)
C        signals. Occurrence of this error results
C        from the VOXSCL setting below the needed value for
C        the data.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 11-JUN-2004 (EDW)
C
C        Added check on AVAL to ensure it's smaller
C        than the size of MAXVAL.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     AB linked list
C
C-&

C
C     SPICE functions.
C
      LOGICAL               RETURN


C
C     Standard RETURN test.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF

C
C     Checkin, then test the array index.
C
      CALL CHKIN  ( 'ADDLNK' )

      IF ( AVAL .GT. MAXVAL ) THEN
         CALL SETMSG ( 'Index larger than array. '//
     .                 'Index = #1. Array size = #2.')
         CALL ERRINT ( '#1', AVAL                     )
         CALL ERRINT ( '#2', MAXVAL                   )
         CALL SIGERR ( 'SPICE(ARRAYTOOSMALL)'         )
         CALL CHKOUT ( 'ADDLNK'                       )
         RETURN
      END IF

C
C     Increment the cell counter.
C
      NCELL = NCELL + 1
 
C
C     Update the cell address of the last occurence of the A-value,
C     if any. If none, PNTRS(AVAL) has value -1.
C
      CELLS(1,NCELL) = BVAL
      CELLS(2,NCELL) = PNTRS(AVAL)

      PNTRS(AVAL)    = NCELL

      CALL CHKOUT ( 'ADDLNK' )

      RETURN
      END
