C
C     Include Section: Plate Model Maxima
C
C        pltmax.inc  Version 2  21-June-2002  (JAB)
C
C        pltmax.inc  Version 1  09-April-1997 (JAB)
C
C
C     The maximum number of bodies, vertices and
C     plates in a plate model or collective thereof are
C     provided here.
C
C     These values can be used to dimension arrays, or to
C     use as limit checks.
C
C     The value of MAXPLT is determined from MAXVRT via
C     Euler's Formula for simple polyhedra having triangular
C     faces.  It is a suggestive value only, as some plate
C     models may be used that are not simple polyhedra,
C     like spacecraft, planetary rings, etc.
C
 
C
C     MAXBOD is the maximum number of bodies the triangular
C            plate model software will support.
C
C     INTEGER               MAXBOD
C     PARAMETER           ( MAXBOD = 20           )

      INTEGER               MAXBOD
      PARAMETER           ( MAXBOD = 1            )
 
C
C     MAXVRT is the maximum number of vertices the triangular
C            plate model software will support.
C
      INTEGER               MAXVRT
      PARAMETER           ( MAXVRT = 1750000         )
 
C
C     MAXPLT is the maximum number of plates that the triangular
C            plate model software will support.
C
      INTEGER               MAXPLT
      PARAMETER           ( MAXPLT = 2*(MAXVRT - 2) )

C
C     MAXNPV is the maximum allowed number of vertices, 
C     not taking into account shared vertices. 
C
      INTEGER               MAXNPV
      PARAMETER           ( MAXNPV = 10*MAXPLT )

C
C     MAXEDG is the maximum allowed number of vertex or plate 
C     neighbors a vertex may have. 
C
      INTEGER               MAXEDG
      PARAMETER           ( MAXEDG = 120 )

C
C     MAXCLN is the maximum length of a kernel comment line. 
C
      INTEGER               MAXCLN
      PARAMETER           ( MAXCLN = 255       )

C
C     MAXCOM is the maximum number of comment lines in the 
C            plate kernel. 
C
      INTEGER               MAXCOM
      PARAMETER           ( MAXCOM = 1000         )

C
C     The maximum 'Q' value for Gaskell shape models. This value
C     is always a multiple of 4.
C
      INTEGER               MAXQ
      PARAMETER           ( MAXQ = 512            )

 
 
C
C     End Include Section: Plate Model Maxima
C
