C$Procedure TRVLNK ( Traverse AB cell linked-list )
 
      SUBROUTINE TRVLNK ( AVAL, MAXVAL, PNTRS, CELLS, NB, BLIST )
      IMPLICIT NONE

C$ Abstract
C
C     Traverse the linked list, searching for
C     all cells that contain the A-value.
C     Store the associated B-values in an array.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     linked list
C
C$ Declarations
  
      INTEGER               AVAL
      INTEGER               MAXVAL
      INTEGER               PNTRS  ( * )
      INTEGER               CELLS  ( 2, * )
      INTEGER               NB
      INTEGER               BLIST  ( * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVAL       I   A-value.
C     PNTRS      I   Array of pointers to the last occurrence of
C                    an A-value in the AB cell linked list CELLS.
C     CELLS      I   Cells containing A, B values and backward pointers.
C     NB         O   Number of B values found.
C     BLIST      O   List of B values.
C
C$ Detailed_Input
C
C     AVAL       A-value.
C
C     PNTRS      Array containing the pointer to the last
C                entry in CELLS containing a particular A-value.
C
C     CELLS      Cells containing an A-value, an associated B-value
C                and a backward pointer to the cell (if any)
C                containing the same A-value.
C
C$ Detailed_Output
C
C     NB         Number of associated B-values found.
C
C     BLIST      List of associated B-values.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) If the array index AVAL exceeds the decalared 
C        size of the PNTR array, the error SPICE(ARRAYTOOSMALL)
C        signals. Occurrence of this error results
C        from the VOXSCL setting below the needed value for
C        the data.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 11-JUN-2004 (EDW)
C
C        Added check on AVAL to ensure it's smaller
C        than the size of MAXVAL.
C
C-    SPICELIB Version 1.0.1, 26-AUG-2002 (BVS)
C
C        Replaced WRITE with normal error reporting calls.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     AB cells
C
C-&
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               PTR
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'TRVLNK' )

      IF ( AVAL .GT. MAXVAL ) THEN
         CALL SETMSG ( 'Index larger than array. '//
     .                 'Index = #1. Array size = #2.' )
         CALL ERRINT ( '#1', AVAL                     )
         CALL ERRINT ( '#2', MAXVAL                   )
         CALL SIGERR ( 'SPICE(ARRAYTOOSMALL)'         )
         CALL CHKOUT ( 'TRVLNK'                       )
         RETURN
      END IF
 
      NB  = 0
      PTR = PNTRS(AVAL)
 
      DO WHILE( PTR .NE. -1 )
  
         NB        = NB + 1
         BLIST(NB) = CELLS(1,PTR)
         I         = CELLS(2,PTR)
         PTR       = I
  
      END DO
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'TRVLNK' )
 
      RETURN
      END
