C$Procedure UNTNGL ( untangle an AB linked-cell list  )

      SUBROUTINE UNTNGL ( NPTR  , INPTR, MAXB   , CELLS, 
     .                    OUTPTR, NOUT , OUTLST )
      IMPLICIT NONE

C$ Abstract
C
C     Untangle an unsorted AB linked-cell list into
C     an A-index and associated B-list.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     AB linked list
C
C$ Declarations

      INTEGER               NPTR
      INTEGER               INPTR     ( * )
      INTEGER               MAXB
      INTEGER               CELLS     ( 2, * )
      INTEGER               OUTPTR    ( * )
      INTEGER               NOUT
      INTEGER               OUTLST    ( * )

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NPTR       I   Length of A-list.
C     INPTR      I   Pointers into AB cell linked-list.
C     MAXB       I   Maximum allowed dimension of B list.
C     CELLS      I   AB cell linked list.
C     OUTPTR     O   A-index array.
C     NOUT       O   Length of B-list.
C     OUTLST     O   B-list.
C
C$ Detailed_Input
C
C     NPTR
C
C     INPTR
C
C     MAXB
C
C$ Detailed_Output
C
C     OUTPTR
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) The routine signals the error SPICE(ARRAYTOOSMALL)
C        if the maximum index (NPTR) applied to the OUTLST array
C        exceeds maximum index (MAXB) of OUTLST. In most cases,
C        MAXB describes the measure on the array.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.1.3, 16-JUL-2004 (EDW)
C
C        Added check on NPTR to ensure it's smaller
C        than the size of the pointer arrays.
C
C        Removed use of BVAL array, TRVLNK now directly
C        writes to OUTLST array.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&

C$ Index_Entries
C
C     AB linked list
C
C-&

C
C     SPICELIB functions
C
      LOGICAL               RETURN


C
C     Local Variables
C
      INTEGER               AVAL
      INTEGER               PTRDEX

C
C     Standard SPICE error handling.
C

      IF ( RETURN() ) THEN
         RETURN
      END IF

      CALL CHKIN  ( 'UNTNGL' )

      IF ( NPTR .GT. MAXB ) THEN
         CALL SETMSG ( 'Index larger than array. '//
     .                 'Index = #1. Array size = #2.')
         CALL ERRINT ( '#1', NPTR                    )
         CALL ERRINT ( '#2', MAXB                    )
         CALL SIGERR ( 'SPICE(ARRAYTOOSMALL)'        )
         CALL CHKOUT ( 'UNTNGL'                      )
         RETURN

      END IF

C
C     Initialize pointer index.
C
      PTRDEX = 0

C
C     Loop over all A-values.
C
      DO AVAL = 1, NPTR

C
C        Traverse the chained list for a particular A-value 
C        and collect associated B-values. If B-values exists,
C        return the number of B-vals to the OUTLST array
C        at element PTRDEX + 1; return the list of B-vals
C        starting at element PTRDEX + 2.
C
         CALL TRVLNK ( AVAL, MAXB, INPTR, CELLS,
     .                       OUTLST(PTRDEX + 1), 
     .                       OUTLST(PTRDEX + 2) )

C
C        Increment pointer PTRDEX if we found any B-vals.
C
         IF ( OUTLST(PTRDEX + 1) .NE. 0 ) THEN

C
C           Increment PTRDEX to the position in
C           OUTLST holding the number of B-vals.
C
            PTRDEX       = PTRDEX + 1

C
C           Store the pointer value in OUTPTR.
C
            OUTPTR(AVAL) = PTRDEX
            
C
C           Increment PTRDEX to mark the position of the final
C           B-val.
C
            PTRDEX       = PTRDEX +  OUTLST(PTRDEX)

         ELSE
C
C           If no associated B-values exist, set the
C           OUTPTR element to -1, indicating no B-value.
C
            OUTPTR(AVAL) = -1

         END IF

      END DO

C
C     Return the current pointer value.
C
      NOUT = PTRDEX

C
C     Standard SPICE error handling.
C
      CALL CHKOUT ( 'UNTNGL' )

      RETURN
      END
