C$Procedure ZZCHKREP ( Check for repeated vertices. )

      SUBROUTINE ZZCHKREP( VALUE, FLAG )
      IMPLICIT NONE

C$ Abstract
C
C     This set of simple entry points records vertices
C     tested against a plate for maximum elevation
C     calculations.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     plate mask
C
C$ Declarations

      INCLUDE 'pltmax.inc'

      INTEGER    VALUE
      LOGICAL    FLAG

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VALUE      I   A vertex ID to store or check.
C     FLAG       O   Boolean indicating stored status.
C
C$ Detailed_Input
C
C     VALUE      A vertex ID to store in the COPY array or the ID value
C                to check for the corresponding  storage status, FALSE
C                if previously stored, TRUE if not stored.
C
C$ Detailed_Output
C
C     FLAG       The boolean result of check for a vertex ID storage 
C                status. FLAG returns TRUE if the ID is not present in
C                the COPY array.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) The error SPICE(BOGUSENTRY) signals on any
C        direct call to ZZCHKREP.
C
C$ Particulars
C
C     The MKMASK subroutine determines the maximum posible
C     elevation of one plate vs. all others as part of the
C     horizon mask generation. This set of entry points
C     prevents multiple elevation calculations on the same
C     vertex. Such an event can occur since one vertex may
C     be an element of than one plate.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     E. D. Wright      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    PLATELIB Version 1.0.0, 03-JUL-2004 (EDW)
C
C-&
 
C$ Index_Entries
C
C     plate mask
C
C-&
 
C
C     Local Variables.
C

      LOGICAL    COPY( 3*MAXPLT)

      INTEGER    I
      INTEGER    VALUE1
      INTEGER    VALUE2
      INTEGER    VALUE3

      SAVE

      CALL CHKIN( 'ZZCHKREP' )

C
C     This routine should never be called. If called,
C     signal an error.
C
      CALL SETMSG ( 'ZZCHKREP: You have called an entry that '       //
     .              'performs no run-time function. This may '       //
     .              'indicate a bug. Please check the documentation '//
     .              'for the subroutine ZZCHKREP.' )
 
      CALL SIGERR ( 'SPICE(BOGUSENTRY)' )
 
      CALL CHKOUT ( 'ZZCHKREP' )


      RETURN


      ENTRY CHKINI ()

C
C     Initialize the COPY array to TRUE.
C
      DO I = 1, 3*MAXPLT, 3
         COPY(I  ) = .TRUE.
         COPY(I+1) = .TRUE.
         COPY(I+2) = .TRUE.
      END DO

      RETURN


      ENTRY CHKREP ( VALUE1, VALUE2, VALUE3 )

C
C     Set the COPY array entry to FALSE for each of
C     the three vertices. This block runs faster
C     if we just set the entries to FALSE regardles
C     of the existing value.
C
      COPY(VALUE1) = .FALSE.
      COPY(VALUE2) = .FALSE.
      COPY(VALUE3) = .FALSE.

      RETURN


      ENTRY CHKTST ( VALUE, FLAG )

C
C     Return the boolean state of the VALUE
C     element in the COPY array. We return TRUE
C     if the COPY array lacks a corresponding entry.
C
      FLAG = COPY(VALUE)

      RETURN
      END

C12345678901234567890123456789012345678901234567890123456789012345678912
