C$Procedure    BBINFO  ( bounding box limits and face normals )
 
      SUBROUTINE BBINFO ( NVOX, VOXSIZ, VOXORI, BBLIM, BBNORM )
 
C$ Abstract
C
C     Set of entry points to load and get bounding
C     box limits and face normals.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     voxel grid bounding box
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NVOX      ( 3 )
 
      DOUBLE PRECISION      VOXSIZ
      DOUBLE PRECISION      VOXORI    ( 3 )
      DOUBLE PRECISION      BBLIM     ( 2, 3 )
      DOUBLE PRECISION      BBNORM    ( 3, 6 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NVOX       I   Dimension of voxel grid in voxel units.
C     VOXSIZ     I   Size of voxel in model units.
C     VOXORI     I   Origin of voxel grid in model units.
C     BBLIM      O   Limits of voxel grid in model units.
C     BBNORM     O   Bounding box face normals in model units.
C
C$ Detailed_Input
C
C     NVOX       Dimension of voxel grid in voxel units.
C
C     VOXSIZ     Size of voxel in model units.
C
C     VOXORI     Origin of voxel grid in model units.
C
C$ Detailed_Output
C
C     BBLIM      Lower and upper coordinate bounds in each
C                dimension of voxel grid (in model units).
C
C     BBNORM     Bounding box face normal vectors in model units.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
      INTEGER               I
      INTEGER               J
 
      LOGICAL               RETURN
      LOGICAL               FIRST
 
      DOUBLE PRECISION      BBLM      ( 2, 3 )
      DOUBLE PRECISION      BBNRM     ( 3, 6 )
 
      SAVE  FIRST
      SAVE  BBNRM
      SAVE  BBLM
 
 
      DATA  FIRST / .TRUE. /
 
      DATA  BBNRM / -1.D0,  0.D0,  0.D0,
     .               1.D0,  0.D0,  0.D0,
     .               0.D0, -1.D0,  0.D0,
     .               0.D0,  1.D0,  0.D0,
     .               0.D0,  0.D0, -1.D0,
     .               0.D0,  0.D0,  1.D0   /
 
C
C     Nobody should call BBINFO directly.
C
 
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'BBINFO' )
 
C
C     This routine should never be called. If this routine is called,
C     an error is signaled.
C
 
      CALL SETMSG ( 'BBINFO: You have called an entry which performs '//
     .              'performs no run-time function. This may '        //
     .              'indicate a bug. Please check the documentation ' //
     .              'for the subroutine PLTMGR.' )
 
      CALL SIGERR ( 'SPICE(BOGUSENTRY)' )
 
      CALL CHKOUT ( 'BBINFO' )
 
      RETURN
 
 
C$Procedure  BBLOAD  ( load bounding box values )
 
      ENTRY BBLOAD ( NVOX, VOXSIZ, VOXORI )
 
C$ Abstract
C
C     Load bounding box values into memory.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
 
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NVOX       I   Dimension of voxel grid in voxel units.
C     VOXSIZ     I   Size of voxel in model units.
C     VOXORI     I   Origin of voxel grid in model units.
C
C$ Detailed_Input
C
C     NVOX       Dimension of voxel grid in voxel units.
C
C     VOXSIZ     Size of voxel in model units.
C
C     VOXORI     Origin of voxel grid in model units.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     load bounding box limits and face normals
C
C-&

 
C
C     If this routine is called for the first time,
C     compute the voxel grid's bounding box limits.
C
 
      IF ( FIRST ) THEN
 
         DO I = 1, 3
            BBLM(1,I) = VOXORI(I)
            BBLM(2,I) = VOXORI(I) + DBLE(NVOX(I))*VOXSIZ
         END DO
 
         FIRST = .FALSE.
 
      END IF
 
      RETURN
 
 
 
C$Procedure  BBGET  ( Get bounding box values )
 
      ENTRY BBGET ( BBLIM, BBNORM )
 
C$ Abstract
C
C     Copy saved values into output parameters.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
 
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BBLIM      O   Limits of voxel grid in model units.
C     BBNORM     O   Bounding box face normals in model units.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     BBLIM      Lower and upper coordinate bounds in each
C                dimension of voxel grid (in model units).
C
C     BBNORM     Bounding box face normal vectors in model units.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     get bounding box limits and face normals
C
C-&
 
 
      DO J = 1, 3
         DO I = 1, 2
            BBLIM(I,J)  = BBLM(I,J)
         END DO
      END DO
 
      DO J = 1, 6
         DO I = 1, 3
            BBNORM(I,J) = BBNRM(I,J)
         END DO
      END DO
 
 
      RETURN
      END
