C$Procedure   DOSHAD   ( Set/return shadow processing flag )
 
      LOGICAL FUNCTION DOSHAD ( VALUE )
 
C$ Abstract
C
C     Set and/or return the shadow processing flag.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     plate shadow flag
C
C$ Declarations
 
      IMPLICIT NONE
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VALUE      I   Sets value of shadow processing flag.
C
C     The function DOSHAD returns .TRUE. or .FALSE., depending on
C     stored value of shadow processing flag in combination with VALUE.
C
C$ Detailed_Input
C
C     VALUE     -1, set internal flag to .FALSE., return .FALSE.
C                0, return current value of internal flag.
C               +1, set internal flag to .TRUE., return .TRUE.
C
C$ Detailed_Output
C
C     See Detailed_input.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 26-AUG-2002 (BVS)
C
C        Replaced WRITE with normal error reporting calls.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     set or return shadow processing flag
C
C-&
 
      INTEGER               VALUE
 
      LOGICAL               DOIT
      LOGICAL               FIRST
      LOGICAL               RETURN
 
      SAVE  DOIT
      SAVE  FIRST
 
      DATA  DOIT  / .TRUE. /
      DATA  FIRST / .TRUE. /
 
 
 
      IF ( FIRST ) THEN
         DOSHAD = DOIT
         FIRST = .FALSE.
         RETURN
      END IF

C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'DOSHAD' )

 
      IF ( VALUE .EQ. -1 ) THEN
         DOIT = .FALSE.
         DOSHAD = DOIT
      ELSE IF ( VALUE .EQ. 0 ) THEN
         DOSHAD = DOIT
      ELSE IF ( VALUE .EQ. 1 ) THEN
         DOIT = .TRUE.
         DOSHAD = DOIT
      ELSE IF ( (VALUE.LT.-1) .OR. (VALUE.GT.1) ) THEN
         CALL SETMSG ( 'VALUE has illegal value = #.' )
         CALL ERRINT ( '#', VALUE                     )
         CALL SIGERR ( 'SPICE(ILLEGALVALUE)'          )
         CALL CHKOUT ( 'DOSHAD'                       )
         RETURN
      END IF
 
C
C     Standard SPICELIB error handling.
C
      CALL CHKOUT ( 'DOSHAD' )
 
      RETURN
      END
