C$Procedure  ELEV  ( return elevation angle )
 
      DOUBLE PRECISION FUNCTION ELEV ( NORM, A, P )
 
C$ Abstract
C
C     Determine the complement of the angle between
C     vector NORM and vector AP.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     ANGLE
C
C$ Declarations
 
      IMPLICIT NONE
 
      DOUBLE PRECISION      A      ( 3 )
      DOUBLE PRECISION      P      ( 3 )
      DOUBLE PRECISION      NORM   ( 3 )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NORM       I   plate normal vector
C     A          I   vector to a point on the edge of the plate
C     P          I   vector to an arbitrary point not on the plate
C
C     The function returns the complement of the angle between
C     NORM and AP (the apparent elevation of P as seen from A).
C
C$ Detailed_Input
C
C     NORM       plate normal vector
C     A          vector to a point on the edge of the plate
C     P          ector to an arbitrary point not on the plate
C
C$ Detailed_Output
C
C     The function returns the complement of the angle between
C     NORM and AP (the apparent elevation of P as seen from A).
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     TBD
C
C$ Examples
C
C     TBD
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 12-MAR-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     angle
C
C-&
 
      DOUBLE PRECISION      DPR
      DOUBLE PRECISION      VSEP
      DOUBLE PRECISION      AP     ( 3 )
 
 
      CALL VSUB ( P, A, AP )
 
      ELEV = 90.D0 - ( DPR() * VSEP ( NORM, AP ) )
 
      RETURN
      END
