C$Procedure ID2VOX ( Voxel index to coordinates )
 
      SUBROUTINE ID2VOX ( IXYZ, NVOX, VIXYZ )
 
C$ Abstract
C
C     Given a voxel's index value, return its integral voxel
C     grid coordinates.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     voxel index
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               IXYZ
      INTEGER               NVOX   ( 3 )
      INTEGER               VIXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IXYZ       I   Voxel index.
C     NVOX       I   Dimensions of voxel grid.
C     VIXYZ      O   Integral voxel coordinates.
C
C$ Detailed_Input
C
C     IXYZ       The integer voxel index for a voxel ranging 
C                from 1 to NVOX(1)*NVOX(2)*NVOX(3). The ID
C                to coord mapping is a bijection.
C
C     NVOX       An integer 3-vector defining the span of
C                the cubic voxels for each coordinate axis. 
C
C                   NVOX(1) = NINT( X         - X         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(2) = NINT( Y         - Y         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(3) = NINT( Z         - Z         )
C                                    Vox_max     Vmin_min
C
C                Where:
C
C                      X          Y          Z
C                       Vox_max    Vox_max    Vox_max
C
C                represent the maximum values of all voxel
C                space coordinates along each axis, and:
C
C                      X          Y          Z
C                       Vox_min    Vox_min    Vox_min
C
C                represent the minimum values of all voxel
C                space coordinates along each axis. 
C
C                NINT being the FORTRAN "nearest integer" function.
C
C$ Detailed_Output
C
C     VIXYZ      Integral coordinates of the voxel; values lie in
C                the ranges (1 to NVOX(1), 1 to NVOX(2), 1 to NVPX(3)).
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.2, 20-SEP-2004 (EDW)
C
C        Extended header documentation.
C
C        Subroutine renamed from GETXYZ.
C
C-    SPICELIB Version 1.0.1, 19-FEB-2000 (JAB)
C
C        Removed SAVED variables.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     voxel index to coordinates
C
C-&
 
      INTEGER               IX
      INTEGER               IY
      INTEGER               IZ
      INTEGER               NX
      INTEGER               NY
      INTEGER               IXY
      INTEGER               NXNY
 
      LOGICAL               RETURN
 
C
C     Standard SPICE error handling.
C 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'ID2VOX' )

C
C     Compute and save constants.
C
      NX    = NVOX(1)
      NY    = NVOX(2)
      NXNY  = NX*NY
 
      IZ  = INT ( IXYZ / NXNY )
      IXY = MOD ( IXYZ, NXNY )
 
      IF ( IXY .GT. 0 ) THEN
         IZ = IZ + 1
      ELSE
         IXY = NXNY
      END IF
 
      IY = 1 + INT ( IXY / NX )
      IX = MOD ( IXY, NX ) 
 
      IF ( IX .EQ. 0 ) THEN
         IX = NX
         IY = IY - 1
      END IF
 
      VIXYZ(1) = IX
      VIXYZ(2) = IY
      VIXYZ(3) = IZ
      

C
C     Checkout of the error system, return.
C 
      CALL CHKOUT ( 'ID2VOX' )
 
      RETURN
      END
