C$Procedure      INILNK ( Initialize an AB cell linked-list )
 
      SUBROUTINE INILNK ( MAXP, MAXC, NCELL, PNTRS, CELLS )
 
C$ Abstract
C
C     Initialize an AB cell linked-list
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     AB linked list
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               MAXC
      INTEGER               MAXP
      INTEGER               NCELL
      INTEGER               PNTRS  ( * )
      INTEGER               CELLS  ( 2, * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     MAXP       I   Maximum length of A-value list.
C     MAXC       I   Maximum number of cells.
C     NCELL      O   Number of populated cells.
C     PNTRS      O   Pointers to last populated cell with A-value
C     CELLS      O   Cells containing A, B values and pointers.
C
C$ Detailed_Input
C
C     MAXP       maximum number of pointers to A-value threads.
C     MAXC       maximum number of cells.
C
C$ Detailed_Output
C
C     NCELL      Number of populated cells.
C
C     PNTRS      Pointers to the last cell containing a particular
C                A-value.
C
C     CELLS      Three consequtive integers comprised of an
C                A-value, a B-value and a pointer to the previous
C                occurrence of the A-value in the list.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     initialize an AB cell linked-list
C
C-&
 
      INTEGER               I
      LOGICAL               RETURN

      IF ( RETURN () ) THEN
         RETURN
      END IF

C
C     Initialize pointer array and cells.
C 
      DO I = 1, MAXP
         PNTRS(I) = -1
      END DO
 
      DO I = 1, MAXC
         CELLS(1,I) = -1
         CELLS(2,I) = -1
      END DO
 
      NCELL = 0
 
      RETURN
      END
