C$Procedure  PINFOV  ( point and view volume )
 
      LOGICAL FUNCTION PINFOV ( NSIDES, NORMLS, APEX, POINT )
 
C$ Abstract
C
C     Given a convex pyramidal view volume,
C     determine if a point is outside or inside.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     FOV
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NSIDES
      DOUBLE PRECISION      NORMLS     ( 3, NSIDES ) 
      DOUBLE PRECISION      APEX       ( 3 )
      DOUBLE PRECISION      POINT      ( 3 )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NSIDES     I   Number of sides of view volume.
C     NORMLS     I   Normals to the planes that contain the
C                    sides of the view volumes.
C     APEX       I   The apex of the view volume.
C     POINT      I   Coordinates of the point to locate inside or
C                    outside the view volume.
C     PINFOV     O   Return .TRUE, if POINT is inside the view volume,
C                    .FALSE. if it's outside or on the edge.
C
C$ Detailed_Input
C
C     NSIDES     Number of sides of view volume.
C
C     NORMLS     Normals to the planes that define the
C                sides of the view volumes. These normals must point
C                inwards toward the interior of the volume.
C
C     APEX       The position of the observer, the apex of the view
C                volume pyramid. This position exists in all planes
C                defining the sides of the volumes.
C
C     POINT      Coordinates of the point to locate inside or
C                outside the view volume.
C
C$ Detailed_Output
C
C     PINFOV     Return .TRUE, if POINT is strictly inside the 
C                view volume, .FALSE. if it's outside or on the edge.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof     (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 02-SEP-2004 (EDW)
C
C        Updates to header and comments.
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     determine if point is inside view volume
C
C-&
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               IP
      INTEGER               PINHFS
 
      PINFOV = .FALSE.
 
C
C     Standard SPICELIB error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'PINFOV' )
 
C
C     Loop over the normal of each polygon side.
C     3-vector NORMLS(*,I) is the normal to side I.
C
      DO I = 1, NSIDES

C
C        Return the flag indicating where the POINT lies 
C        with respect to the APEX and NORMLS(*,I).
C
         IP = PINHFS ( POINT, APEX, NORMLS(1,I) )
      
C
C        Return with .FALSE. if the POINT does not 
C        exist in the I halfplane.
C
         IF ( IP .LT. 1 ) THEN
            CALL CHKOUT ( 'PINFOV' )
            RETURN
         END IF
      
      END DO
 
      PINFOV = .TRUE.
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'PINFOV' )
 
 
      RETURN
      END
