C$Procedure      PLCENT ( Plate Center)
 
      SUBROUTINE PLCENT ( P, CENTER )
 
C$ Abstract
C
C    Compute the center of a triangle "plate" in 3-space.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     GEOMETRY
C
C$ Declarations
 
      IMPLICIT              NONE
 
      DOUBLE PRECISION      P         ( 3, 3 )
      DOUBLE PRECISION      CENTER    ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     P          I   The vertices of a triangle in 3-space.
C     CENTER     O   The coordinates of the "center" of the triangle
C
C     The function returns
C
C$ Detailed_Input
C
C     P          is an array containing the coordinates of the
C                vertices of a triangle in 3-space. The coordinates
C                of the I'th vertex are given by the triple:
C
C                 (  P(1,I), P(2,I), P(3,I)  )
C
C$ Detailed_Output
C
C     CENTER     is the vector average of the vertices of the
C                triangle.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine is simply a FORTRAN macro for computing the
C     vector average of 3 vectors in 3-space.
C
C$ Examples
C
C     Suppose you need to compute the center of a triangle
C     in 3-space.  Here's how you could use this routine to
C     accomplish the task.  (Note that unless you're vertices
C     are automatically loaded in to the array P, this is
C     probably more trouble than it's worth.)
C
C
C        P(1,1) = x-coordinate of first vertex
C        P(2,1) = y-coordinate of first vertex
C        P(3,1) = z-coordinate of first vertex
C
C        P(1,2) = x-coordinate of second vertex
C        P(2,2) = y-coordinate of second vertex
C        P(3,2) = z-coordinate of second vertex
C
C        P(1,3) = x-coordinate of third vertex
C        P(2,3) = y-coordinate of third vertex
C        P(3,3) = z-coordinate of third vertex
C
C     Now to get the center just call PLCENT
C
C        CALL PLCENT ( P, CENTER )
C
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 17-JUN-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     Compute the center of a triangle
C
C-&
C
C     Local Variables
C
      INTEGER               I
 
C
C     Average the values of each component over all vertices.
C
 
      DO I = 1, 3
         CENTER(I) = ( P(I,1) + P(I,2) + P(I,3) ) / 3.D0
      END DO
 
      RETURN
      END
