C$Procedure PLTMGR ( Plate model manager )
 
      SUBROUTINE PLTMGR ( EKFILE,  BODNAM,  BODEX,   NAFID,
     .                    PLDEX,   CENVEC,  NRMVEC,  PLTID,
     .                    VRDEX,   VRTID,   VINPLT,  VLOUT,
     .                    VOUT,    ALBOUT,  NVSET,   EDGVRT,
     .                    NUMPLT,  PLATES,  NBTOTL,  NPTOTL,
     .                    NVTOTL,  NAFIDS,  NPLATS,  PLBNDS,
     .                    NVERTS,  VRBNDS,  NPLT,    PLBND,
     .                    NVRT,    VRBND,   DESCR,   CRTOR,
     .                    CRDAT,   VERS,    BMIN,    BMAX,
     .                    PLAREA,  NRMUN,   NCOM,    COMS,
     .                    LNGSID,  MSKFLG,  NVOX,
     .                    VOXSIZ,  VOXORI,  NVXTOT,  NVX,
     .                    VOXID,   NPINVX,  PVXLST,  MAXELE )

C$ Abstract
C
C     Manage plate model data storage and retrieval.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     MKPLAT
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
 
      IMPLICIT NONE
 
      INCLUDE               'pltmax.inc'
      INCLUDE               'ekcnamsz.inc'
      INCLUDE               'ektnamsz.inc'
 
 
      CHARACTER*(*)         EKFILE
      CHARACTER*(*)         BODNAM
      INTEGER               BODEX
      INTEGER               NAFID
      INTEGER               PLDEX
      DOUBLE PRECISION      CENVEC    ( 3 )
      DOUBLE PRECISION      NRMVEC    ( 3 )
      INTEGER               PLTID
 
      INTEGER               VRDEX
      INTEGER               VRTID
      DOUBLE PRECISION      VINPLT    ( 3, 3 )
      INTEGER               VLOUT     ( 3 )
 
      DOUBLE PRECISION      VOUT      ( 3 )
      DOUBLE PRECISION      ALBOUT
      INTEGER               NVSET
      INTEGER               EDGVRT    ( * )
 
      INTEGER               NUMPLT
      INTEGER               PLATES    ( * )
      INTEGER               NBTOTL
      INTEGER               NPTOTL
 
      INTEGER               NVTOTL
      INTEGER               NAFIDS    ( * )
      INTEGER               NPLATS    ( * )
      INTEGER               PLBNDS    ( 2, * )
 
      INTEGER               NVERTS    ( * )
      INTEGER               VRBNDS    ( 2, * )
      INTEGER               NPLT
      INTEGER               PLBND     ( 2 )
 
      INTEGER               NVRT
      INTEGER               VRBND     ( 2 )
      CHARACTER*(*)         DESCR
      CHARACTER*(*)         CRTOR
 
      CHARACTER*(*)         CRDAT
      INTEGER               VERS
      DOUBLE PRECISION      BMIN      ( 3 )
      DOUBLE PRECISION      BMAX      ( 3 )
      DOUBLE PRECISION      PLAREA
 
      DOUBLE PRECISION      NRMUN     ( 3 )
      INTEGER               NCOM
      CHARACTER*(*)         COMS      ( * )
      DOUBLE PRECISION      LNGSID
 
      INTEGER               MSKFLG
      INTEGER               NVOX      ( 3 )
 
      DOUBLE PRECISION      VOXSIZ
      DOUBLE PRECISION      VOXORI    ( 3 )
      INTEGER               NVXTOT
      INTEGER               NVX
 
      INTEGER               VOXID
      INTEGER               NPINVX
      INTEGER               PVXLST    ( * )
      DOUBLE PRECISION      MAXELE
 
C$ Brief_I/O
C
C     VARIABLE  I/O  ENTRY
C     --------  ---  --------------------------------------------------
C     EKFILE     I   INPLAT
C     BODNAM     I   NAM2DX
C                O   DX2NAM, PLTOT
C     BODEX      I   DX2NAM, DX2BID, PLTIDX, VRTIDX, PLTBND, PLHEAD
C                O   NAM2DX, BID2DX, NTHPLI, NTHVRI
C     NAFID      I   BID2DX
C                O   DX2BID, PLHEAD
C
C     PLDEX      I   NTHPLC, NTHPLN, NTHPLI, NTHPLV, NTHPVL, NTHALB
C                O   PLTIDX
C     CENVEC     O   NTHPLC
C     NRMVEC     O   NTHPLN
C     PLTID      I   PLTIDX
C                O   NTHPLI, NTHPVL, NTHALB
C
C     VRDEX      I   NTHVRI, NTHVRT, VRTEDG, VRTPLT
C                O   VRTIDX
C     VRTID      I   VRTIDX
C                O   NTHVRI, NTHVRT
C     VINPLT     O   NTHPLT
C     VLOUT      O   NTHPVL
C
C     VOUT       O   NTHVRT
C     ALBOUT     O   NTHALB
C     NVSET      O   VRTEDG
C     EDGVRT     O   VRTEDG
 
C     NUMPLT     O   NUMPLT
C     PLATES     O   VRTPLT
C     NBTOTL     O   PLSIZE, PLTOT
C     NPTOTL     O   PLSIZE, PLTOT
C
C     NVTOTL     O   PLSIZE, PLTOT
C     NAFIDS     O   PLSIZE
C     NPLATS     O   PLSIZE
C     PLBNDS     O   PLSIZE
C
C     NVERTS     O   PLSIZE
C     VRBNDS     O   PLSIZE
C     NPLT       O   PLTBND, PLHEAD
C     PLBND      O   PLTBND
C
C     NVRT       O   PLTBND, PLHEAD
C     VRBND      O   PLTBND
C     DESCR      O   PLHEAD
C     CRTOR      O   PLHEAD
C
C     CRDAT      O   PLHEAD
C     VERS       O   PLHEAD
C     BMIN       O   BEXTNT
C     BMAX       O   BEXTNT
C     PLAREA
C
C     NTHPUN
C
C
C     MAXBOD     P   INPLAT, UNLDPL, NAM2DX, DX2NAM, BID2DX,
C                    DX2BID, NTHPLI, NTHVRI, PLTIDX, VRTIDX,
C                    PLSIZE, PLTBND
C     MAXVRT     P   INPLAT, NTHPLV, NTHVRT, VRTPLT
C     MAXPLT     P   INPLAT, NTHPLC, NTHPLV, NTHPVL, NTHALB,
C                    VRTEDG
C     MAXNPV     P   INPLAT, VRTEDG, VRTPLT
C     MAXEDG     P   VRTEDG
C
C
C$ Detailed_Input
C
C     See $Local Declarations and the ENTRY points for a discussion
C     of their input arguments.
C
C$ Detailed_Output
C
C     See $Local Declarations and the ENTRY points for a discussion
C     of their output arguments.
C
C$ Parameters
C
C     These values are set in the include file 'pltmax.inc':
C
C     MAXBOD is the maximum number of bodies.
C
C     MAXVRT is the maximum number of vertices that can be stored.
C
C     MAXPLT is the maximum number of plates that can be stored.
C
C     MAXNPV is the maximum number of vertices, not accounting for
C     vertex sharing by plates.
C
C     MAXEDG is the maximum number of vertex or plate neighbors a
C     vertex allowable.
C
C     MAXCOM is the maximum number of comment lines in the plate
C     kernel.
C
C     MAXCLN is the maximum length of the comment lines.
C
C$ Files
C
C     See: $Files in ENTRY points.
C
C$ Exceptions
C
C     1) If PLTMGR is called directly, the error SPICE(BOGUSENTRY) is
C        signaled.
C
C$ Particulars
C
C     PLTMGR must never be called directly, but instead be
C     accessed only through its entry points.
C
C     Plate and vertex information will be stored in saved
C     arrays.  Index arrays will keep track of the beginning and
C     end of each plate model body's data. Related information
C     about the plate model is also stored and saved.
C
C
C     INPLAT ( EKFILE )   Given a file name (EKFILE), opens
C                         and reads the file as a plate model E-kernel,
C                         then initializes plate model buffers.
C
C                         CHARACTER*(*)         EKFILE
C
C     UNLDPL              Unloads all plate kernel data from the plate
C                         model system; resets body, plate and 
C                         vertex counters to zero.
C
C     NAM2DX  ( BODNAM,   Given a body name, return
C               BODEX )   the body index.
C
C                         CHARACTER*(*)         BODNAM
C                         INTEGER               BODEX
C
C     DX2NAM ( BODEX,     Given a body index, return
C              BODNAM )   the body name.
C 
C                         INTEGER               BODEX
C                         CHARACTER*(80)        BDNAME(MAXBOD)
C
C     BID2DX ( NAFID,     Given a NAIF body ID, return
C              BODEX )    the body index.
C
C                         INTEGER               NAFID
C                         INTEGER               BODEX
C
C     DX2BID ( BODEX,     Given a body index, return
C              NAFID )    the NAIF ID.
C 
C                         INTEGER               BODEX
C                         INTEGER               NAFID
C
C     NTHPLC  ( PLDEX,    Given a plate index, return the
C               CENVEC )  coordinates of the plate's center.
C 
C                         INTEGER               PLDEX
C                         DOUBLE PRECISION      CENVEC( 3 )
C
C     NTHPLN ( PLDEX,     Given a plate index, return the
C              NRMVEC )   components of the plate's normal vector.
C 
C                         INTEGER               PLDEX
C                         DOUBLE PRECISION      NRMVEC( 3 )
C
C     NTHPLI ( PLDEX,     Given a plate index, return the
C              BODEX,     body index and the
C              PLTID )    plate ID.
C
C                         INTEGER               PLDEX
C                         INTEGER               BODEX
C                         INTEGER               PLTID
C
C     NTHVRI ( VRDEX,     Given a vertex index, return the
C              BODEX,     body index and the
C              VRTID )    vertex ID.
C
C                         INTEGER               VRDEX
C                         INTEGER               BODEX
C                         INTEGER               VRTID
C
C     NTHPLV ( PLDEX,     Given a plate index, return the
C              VINPLT )   coordinates of the plate's vertices.
C
C                         INTEGER               PLDEX
C                         INTEGER               VINPLT( 3, 3 )
C
C     NTHPVL ( PLDEX,     Given a plate index, return the
C              PLTID,     plate ID and the
C              VLOUT )    list of vertex indices belonging to the plate.
C 
C                         INTEGER               PLDEX
C                         INTEGER               PLTID
C                         INTEGER               VLOUT( 3 )
C
C     NTHVRT ( VRDEX,     Given a vertex index, return the
C              VRTID,     vertex ID and the
C              VOUT )     vertex's cartesian coordinates.
C
C                         INTEGER               VRDEX
C                         INTEGER               VRTID
C                         DOUBLE PRECISION      VOUT( 3 )
C
C     NTHALB ( PLDEX,     Given a plate index, return the
C              PLTID,     plate ID and the
C              ALBOUT )   plate albedo.
C
C                         INTEGER               PLDEX
C                         INTEGER               PLTID
C                         DOUBLE PRECISION      ALBOUT
C
C     NTHSID ( PLDEX,     Given a plate index, return the
C              LNGSID )   length of the plate's longest side.
C
C                         INTEGER               PLDEX
C                         DOUBLE PRECISION      LNGSID
C
C     NTHMSK ( PLDEX,     Given a plate index, return its
C              MSKFLG,    mask flag value,
C              MAXELE )   maximum elevation of horizon.
C
C                         INTEGER               PLDEX
C                         INTEGER               MSKFLG
C                         DOUBLE PRECISION      MAXELE
C
C     NTHPLA ( PLDEX,     Given a plate index, return the
C              PLAREA )   area of the plate.
C
C                         INTEGER               PLDEX
C                         DOUBLE PRECISION      PLAREA
C
C     NTHPUN ( PLDEX,     Given a plate index, return the
C              NRMUN )    components of the plate's unit normal vector.
C
C                         INTEGER               PLDEX
C                         DOUBLE PRECISION      NRMUN   ( 3 )
C
C     VRTEDG ( VRDEX,     Given a vertex index, return the
C              NVSET,     number of vertices edge-connected to it, and
C              EDGVRT )   the list of indices of the connected 
C                         vertices. 
C
C                         INTEGER               

C                         INTEGER               NVSET
C                         INTEGER               EDGVRT( MAXEDG )
C
C     VRTPLT ( VRDEX,     Given a vertex index, return the
C              NUMPLT,    number of plates sharing that vertex, and
C              PLATES )   the list of plate indices.
C
C                         INTEGER               VRDEX
C                         INTEGER               NUMPLT
C                         INTEGER               PLATES( * )
C
C     PLTIDX ( PLTID,     Given a plate ID and a
C              BODEX,     body index, return the
C              PLDEX )    plate index.
C 
C                         INTEGER               PLTID
C                         INTEGER               BODEX
C                         INTEGER               PLDEX
C
C     VRTIDX ( VRTID,     Given a vertex ID and a
C              BODEX,     body index, return the
C              VRDEX )    vertex index.
C
C                         INTEGER               VRTID
C                         INTEGER               BODEX
C                         INTEGER               VRDEX
C
C     PLHEAD ( BODEX,     Given a body index, returns info about kernel:
C              DESCR,     text description of plate model,
C              CRTOR,     name of plate model file creator,
C              CRDAT,     plate model creation date,
C              BODNAM,    text name of body,
C              NAFID,     NAIF ID of body,
C              VERS,      version of plate model,
C              NPLT,      number of plates in model and
C              NVRT    )  number of vertices in model.
C
C                         INTEGER               BODEX
C                         CHARACTER*(*)         DESCR
C                         CHARACTER*(*)         CRTOR
C                         CHARACTER*(*)         CRDAT
C                         INTEGER               NAFID
C                         CHARACTER*(*)         BODNAM
C                         INTEGER               VERS
C                         INTEGER               NPLT
C                         INTEGER               NVRT
C
C     PLSIZE ( NBTOTL,    Return number of plate bodies loaded,
C              NPTOTL,    total number of plates loaded,
C              NVTOTL,    total number of vertices,
C              NAFIDS,    NAIF ID of each loaded body,
C              NPLATS,    list of number of plates for each body,
C              PLBNDS,    start and end plate indices for each body,
C              NVERTS,    list of number of vertices for each body,
C              VRBNDS  )  start and end vertex indices for each body.
C
C                         INTEGER               NBTOT
C                         INTEGER               NPTOT
C                         INTEGER               NVTOT
C                         INTEGER               NAFIDS( * )
C                         INTEGER               NPLATS( * )
C                         INTEGER               PLBNDS( 2, * )
C                         INTEGER               NVERTS( * )
C                         INTEGER               VRBNDS( 2, * )
C
C     PLTBND ( BODEX,     Given a body index, return
C              NPLT,      the number of plates,
C              PLBND,     plate index bounds,
C              NVRT,      number of vertices and
C              VRBND   )  vertex index bounds for that body.
C 
C                         INTEGER               BODEX
C                         INTEGER               NPLT
C                         INTEGER               PLBND( 2 )
C                         INTEGER               NVRT
C                         INTEGER               VRBND( 2 )
C
C     PLTOT  ( NBTOTL,    Return the total number of bodies,
C              NPTOTL,    plates
C              NVTOTL )   and vertices.
C
C                         INTEGER               NBTOTL
C                         INTEGER               NPTOTL
C                         INTEGER               NVTOTL
C
C     BEXTNT ( BODEX,     Given a body index, return
C              BMIN,       the min and max x, y and z body extents.
C              BMAX   )  
C
C                         INTEGER               BODEX
C                         DOUBLE PRECISION      BMIN    ( 3 )
C                         DOUBLE PRECISION      BMAX    ( 3 )
C
C     KERCOM ( BODEX,     Given a body index, return the
C              NCOM,      number of kernel comment lines and
C              COMS  )    the comments themselves.
C
C                         INTEGER               BODEX
C                         INTEGER               NCOM
C                         CHARACTER*(*)         COMS( * )
C
C     VOXSUM ( BODEX,     Given a body index, return the
C              NVOX,      number of voxels in each dimension, the
C              VOXSIZ,    voxel size in model units, the
C              VOXORI,    voxel grid origin in model units, the
C              NVXTOT,    total number of voxels,
C              NVX    )   length of plate-voxel occupation array.
C
C                         INTEGER               BODEX
C                         INTEGER               NVOX  ( 3 )
C                         DOUBLE PRECISION      VOXSIZ
C                         DOUBLE PRECISION      VOXORI( 3 )
C                         INTEGER               NVXTOT
C                         INTEGER               NVX
C
C     VOXPLT ( VOXID,     Given a voxel ID, return the
C              NPINVX,    number of plates occupying the voxel,
C              VXPLST  )  and the list of plate ID's.
C
C                         INTEGER               VOXID
C                         INTEGER               NPINVX
C                         INTEGER               VXPLST( * )
C
C$ Examples
C
C     In progress.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before any other routine is called.
C
C     2) Version 2 allows only one body be loaded at a time.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 2.0.15, XX-YYY-2004 (EDW)
C
C       Under repair.
C
C-    SPICELIB Version 2.0.1, 23-MAR-1999 (JAB)
C
C        Changed INPLAT, MASK and added header comments.
C
C-    SPICELIB Version 2.0.0, 25-OCT-1998 (JAB)
C
C        Altered to read the plate kernel generated
C        by mkplat, Version 2.
C
C-    SPICELIB Version 1.0.0, 04-SEP-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     plate model manager
C
C-&
 
C
C     SPICELIB functions.
C
 
      LOGICAL               EQSTR
      LOGICAL               RETURN
 
 
C
C     Private SPICELIB functions.
C
 
C
C     Local Parameters
C
 
      INTEGER               LBCELL
      PARAMETER           ( LBCELL = -5 )
 
 
C
C     Local declarations.
C
 
 
C
C     PLTMGR              Contains plate model entry points.
C
      INTEGER               I
      INTEGER               J
      INTEGER               K
      INTEGER               NP
      INTEGER               NV
      INTEGER               NVC
      INTEGER               VXN
      INTEGER               NREC
      INTEGER               NROWS
      INTEGER               SEGNO
      INTEGER               HANDLE
      INTEGER               NBTOT
      INTEGER               NPTOT
      INTEGER               NVTOT
      INTEGER               NLINE
      INTEGER               TOTNVX
      INTEGER               BINDEX
      INTEGER               PLTPTR
      INTEGER               VOXPTR
      INTEGER               VRDEX2
      INTEGER               CARDI
      INTEGER               FETCHI
      INTEGER               NEWPLT
      INTEGER               NEWVRT

      INTEGER               VOXN     ( 3 )
      INTEGER               PVLIST   ( MAXEDG )
      INTEGER               PID      ( MAXPLT )
      INTEGER               VID      ( MAXVRT )
      INTEGER               PMASK    ( MAXPLT )
      INTEGER               IVALS    ( MAXPLT )
      INTEGER               NPLTS    ( MAXBOD )
      INTEGER               NVRTS    ( MAXBOD )
      INTEGER               IVER     ( MAXBOD )
      INTEGER               NAIFID   ( MAXBOD )
      INTEGER               VXPNTR   ( MAXNPV )
      INTEGER               VXLIST   ( MAXNPV )
      INTEGER               VCPNTR   ( MAXVRT )
      INTEGER               VCLIST   ( MAXNPV )
      INTEGER               VLIST    ( 3, MAXPLT )
      INTEGER               PBOUND   ( 2, MAXBOD )
      INTEGER               VBOUND   ( 2, MAXBOD )
      INTEGER               VRTSET   ( LBCELL:MAXEDG )

      LOGICAL               FIRST
      LOGICAL               NULLS    ( 1 )
 
      CHARACTER*(CNAMSZ)    COLUMN
      CHARACTER*(80)        CVALS    ( 1 )
      CHARACTER*(80)        BDNAME   ( MAXBOD )
      CHARACTER*(80)        CREATR   ( MAXBOD )
      CHARACTER*(80)        CRDATE   ( MAXBOD )
      CHARACTER*(80)        MODESC   ( MAXBOD )
      CHARACTER*(MAXCLN)    COMMNT   ( MAXCOM )
 
      DOUBLE PRECISION      BXMIN
      DOUBLE PRECISION      BXMAX
      DOUBLE PRECISION      BYMIN
      DOUBLE PRECISION      BYMAX
      DOUBLE PRECISION      BZMIN
      DOUBLE PRECISION      BZMAX
      DOUBLE PRECISION      SIZVOX
      DOUBLE PRECISION      ORIVOX   ( 3 )
      DOUBLE PRECISION      AREA     ( MAXPLT )
      DOUBLE PRECISION      LSIDE    ( MAXPLT )
      DOUBLE PRECISION      DVALS    ( MAXPLT )
      DOUBLE PRECISION      ALBEDO   ( MAXPLT )
      DOUBLE PRECISION      PMAXEL   ( MAXPLT )
      DOUBLE PRECISION      CENTER   ( 3, MAXPLT )
      DOUBLE PRECISION      NORMAL   ( 3, MAXPLT )
      DOUBLE PRECISION      NRMHAT   ( 3, MAXPLT )
      DOUBLE PRECISION      VRTXYZ   ( 3, MAXVRT )
      DOUBLE PRECISION      BODEXT   ( 2, 3, MAXBOD )
 

C
C     Save everything.
C 
      SAVE
 
 
C
C     Initialized variables.
C
      DATA  FIRST   / .TRUE. /
      DATA  NBTOT   / 0 /
      DATA  NPTOT   / 0 /
      DATA  NVTOT   / 0 /
 
 
C
C     Nobody should call PLTMGR directly.
C
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'PLTMGR' )
 
C
C     This routine should never be called. If this routine is called,
C     signal an error.
C
      CALL SETMSG ( 'PLTMGR: You have called an entry that performs ' //
     .              'no run-time function. This may '                 //
     .              'indicate a bug. Please check the documentation ' //
     .              'for the subroutine PLTMGR.' )
 
      CALL SIGERR ( 'SPICE(BOGUSENTRY)' )
 
      CALL CHKOUT ( 'PLTMGR' )
 
      RETURN
 

 
C$Procedure  INPLAT ( Input a plate model E-kernel )
 
      ENTRY INPLAT ( EKFILE )
 
C$ Abstract
C
C     Read a plate model E-kernel and store the header
C     information and plate data in memory.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     MKPLAT
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     EKFILE     I   Pathname of plate model E-kernel file.
C
C
C$ Detailed_Input
C
C     EKFILE     Pathname of plate model E-kernel file.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If an attempt is made to load a shape model for a body
C        already loaded, the error 'SPICE(BODYALREADYLOADED)'
C        is signaled.
C
C     2) If an attempt is made to load more than MAXBOD bodies,
C        the error 'SPICE(TOOMANYBODIESLOADED)' is signaled.
C
C     3) If an attempt is made to load more than MAXPLT plates,
C        the error 'SPICE(PLATEINDEXOUTOFRANGE)' is signaled.
C
C     4) If an attempt is made to load more than MAXVRT vertices,
C        the error 'SPICE(VERTEXINDEXOUTOFRANGE)' is signaled.
C
C     5) If an attempt is made to load more than MAXPLT albedo
C        values, the error 'SPICE(PLATEINDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) EKFILE must be the name of a valid plate model E-kernel file.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 01-AUG-2004 (EDW)
C
C        Added EKCLS call to close the EK. Corrected
C        math error in calculation of PBOUND and VBOUND; 
C        the error restricted use to one plate model.
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     load plate model kernel
C
C-&
 
C
C     Read an E-kernel containing the plate model.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'INPLAT' )
 
      CALL EKOPR ( EKFILE, HANDLE )
 

C
C     Read Segment One (HEADER).
C
      SEGNO = 1
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read header information.  Get NAIF_ID of plate body first
C     to see if that body has already been loaded.
C
 
      COLUMN = 'NAIF_ID'
      NREC = 1
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             IVALS,  NULLS,  NROWS             )
 
 
      IF ( FIRST ) THEN
 
         NBTOT     = 1
         NPTOT     = 0
         NVTOT     = 0
         NAIFID(1) = -1
         FIRST     = .FALSE.
 
      ELSE
 
         DO I = 1, NBTOT

            IF ( NAIFID(I) .EQ. IVALS(1) ) THEN
               CALL SETMSG ( 'Body # was already loaded.   ' )
               CALL ERRINT ( '#', NAIFID(I)                  )
               CALL SIGERR ( 'SPICE(BODYALREADYLOADED)'      )
               CALL CHKOUT ( 'INPLAT'                        )
               RETURN
            END IF

         END DO
 
         NBTOT = NBTOT + 1
 
C
C     The current implementation of the spatial index works 
C     for one body at a time.
C
         IF ( NBTOT .GT. 1 ) THEN
            CALL SETMSG ( 'Number of bodies exceeds one.' )
            CALL SIGERR ( 'SPICE(TOOMANYBODIESLOADED)'    )
            CALL CHKOUT ( 'INPLAT'                        )
            RETURN
         END IF
 
         IF ( NBTOT .GT. MAXBOD ) THEN
            CALL SETMSG ( 'Number of bodies exceeds the '
     .     //             'dimensioned limit of #.      ' )
            CALL ERRINT ( '#', MAXBOD                     )
            CALL SIGERR ( 'SPICE(TOOMANYBODIESLOADED)'    )
            CALL CHKOUT ( 'INPLAT'                        )
            RETURN
         END IF
 
      END IF
 
C
C     Set current body index.
C
      BINDEX = NBTOT
 
C
C     Save the NAIF ID.
C
      NAIFID ( BINDEX ) = IVALS(1)
 
C
C     Get and save the Model Description.
C
      COLUMN = 'MODEL_DESCRIPTION'
      CALL XCOLC ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             CVALS,  NULLS,  NROWS               )
 
      MODESC ( BINDEX ) = CVALS(1)
 
C
C     Get and save the Date Created.
C
      COLUMN = 'CREATED'
      CALL XCOLC ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             CVALS,  NULLS,  NROWS                )
 
      CRDATE ( BINDEX ) = CVALS(1)
 
C
C     Store the name of the Creator.
C
      COLUMN = 'CREATOR'
      CALL XCOLC ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             CVALS,  NULLS,  NROWS                )
 
      CREATR ( BINDEX ) = CVALS(1)
 
C
C     Get and save the Body Name.
C
      COLUMN = 'BODY_NAME'
      CALL XCOLC ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             CVALS,  NULLS,  NROWS               )
 
      BDNAME ( BINDEX ) = CVALS(1)
 
C
C     Get  and save the Version Number.
C
      COLUMN = 'VERSION'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN,  NREC,
     .             IVALS,  NULLS,  NROWS               )
 
      IVER ( BINDEX )  = IVALS(1)
 
C
C     Get and save the Number of Plates.
C
      COLUMN = 'NUM_PLATES'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN,  NREC,
     .             IVALS,  NULLS,  NROWS                )
 
      NP = IVALS(1)
 
      IF ( (NP+NPTOT) .GT. MAXPLT ) THEN
         CALL SETMSG ( 'Plate index is out of range'  )
         CALL SIGERR ( 'SPICE(PLATEINDEXOUTOFRANGE)'  )
         CALL CHKOUT ( 'INPLAT'                       )
         RETURN
      END IF
 
      NPLTS ( BINDEX ) = NP
 
C
C     Get and save the Number of Vertices.
C
      COLUMN = 'NUM_VERTICES'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             IVALS,  NULLS,  NROWS                )
 
      NV = IVALS(1)
 
      IF ( (NV+NVTOT) .GT. MAXVRT ) THEN
         CALL SETMSG ( 'Vertex index is out of range'  )
         CALL SIGERR ( 'SPICE(VERTEXINDEXOUTOFRANGE)'  )
         CALL CHKOUT ( 'INPLAT'                        )
         RETURN
      END IF
 
      NVRTS ( BINDEX ) = NV
 
C
C     Read and store the number of special comment lines.
C
 
      COLUMN = 'NLINES'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             NLINE,  NULLS,  NROWS                )
 
 
C
C     Read Segment Two (VERTEX).
C
 
      SEGNO = 2
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and save the Vertex ID's.
C
      COLUMN = 'VERTEX_ID'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NV,
     .             IVALS,  NULLS,  NROWS              )
 
      DO I = 1, NV
         K      = I + NVTOT
         VID(K) = IVALS(I)
      END DO
 
C
C     Read and save the Vertex Coordinates.
C
C     X components.
C
      COLUMN = 'VERT_X'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NV,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NV
         K           = I + NVTOT
         VRTXYZ(1,K) = DVALS(I)
      END DO
 
C
C     Y components.
C
      COLUMN = 'VERT_Y'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NV,
     .             DVALS,  NULLS,  NROWS              )

      DO I = 1, NV
         K           = I + NVTOT
         VRTXYZ(2,K) = DVALS(I)
      END DO
 
C
C     Z components.
C
      COLUMN = 'VERT_Z'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NV,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NV
         K           = I + NVTOT
         VRTXYZ(3,K) = DVALS(I)
      END DO
 
 
C
C     Read Segment Three (PLATE).
C
 
C
C     Read and save the plate IDs.
C
 
      SEGNO = 3
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
 
      COLUMN = 'PLATE_ID'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             IVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K      = I + NPTOT
         PID(K) = IVALS(I)
      END DO
 
 
C
C     Read and save the plate vertex list.
C     Convert vertex ID's to vertex index values.
C
C     First plate vertex.
C
 
      COLUMN = 'VERT_1'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             IVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K          = I + NPTOT
         VLIST(1,K) = IVALS(I) + NVTOT
      END DO
 
C
C     Second plate vertex.
C
 
      COLUMN = 'VERT_2'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             IVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K          = I + NPTOT
         VLIST(2,K) = IVALS(I) + NVTOT
      END DO
 
C
C     Third plate vertex.
C
 
      COLUMN = 'VERT_3'
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             IVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K          = I + NPTOT
         VLIST(3,K) = IVALS(I) + NVTOT
      END DO
 
 
C
C     Read Segment Four (ALBEDO).
C
 
      SEGNO = 4
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and save Plate Albedos.
C
 
      COLUMN = 'ALBEDO'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS               )
      DO I = 1, NP
         K         = I + NPTOT
         ALBEDO(K) = DVALS(I)
      END DO
 
 
C
C     Read Segment Five (PLATE_INFO).
C
 
      SEGNO = 5
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and save the Plate Unit Normals.
C
C     X components.
C
      COLUMN = 'NORM_X'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K           = I + NPTOT
         NRMHAT(1,K) = DVALS(I)
      END DO
 
C
C     Y components.
C
      COLUMN = 'NORM_Y'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K           = I + NPTOT
         NRMHAT(2,K) = DVALS(I)
      END DO
 
C
C     Z components.
C
      COLUMN = 'NORM_Z'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K           = I + NPTOT
         NRMHAT(3,K) = DVALS(I)
      END DO
 
 
 
C
C     Read and save the Plate Centers.
C
C     X components.
C
      COLUMN = 'CENT_X'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K = I + NPTOT
         CENTER(1,K) = DVALS(I)
      END DO
 
C
C     Y components.
C
      COLUMN = 'CENT_Y'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K = I + NPTOT
         CENTER(2,K) = DVALS(I)
      END DO
 
C
C     Z components.
C
      COLUMN = 'CENT_Z'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS              )
      DO I = 1, NP
         K = I + NPTOT
         CENTER(3,K) = DVALS(I)
      END DO
 
 
C
C     Read and save Plate Areas.
C
      COLUMN = 'AREA'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS               )
      DO I = 1, NP
         K = I + NPTOT
         AREA(K) = DVALS(I)
      END DO
 
C
C     Read and save Length of Longest Side.
C
      COLUMN = 'LONG_SIDE'
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NP,
     .             DVALS,  NULLS,  NROWS               )
      DO I = 1, NP
         K = I + NPTOT
         LSIDE(K) = DVALS(I)
      END DO
 
C
C     Read Segment Six (VOXEL_SUMMARY).
C
 
      SEGNO = 6
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     This segment has Spatial Index summary information.
C
 
C
C     Read and store the number of voxels in each dimension.
C
      COLUMN = 'NVOX_X'
      NREC   = 1
      CALL XCOLI ( EKFILE,    HANDLE, SEGNO, COLUMN, NREC,
     .             VOXN(1),   NULLS,  NROWS                )
 
      COLUMN = 'NVOX_Y'
      NREC   = 1
      CALL XCOLI ( EKFILE,    HANDLE, SEGNO, COLUMN, NREC,
     .             VOXN(2),   NULLS,  NROWS                )
 
      COLUMN = 'NVOX_Z'
      NREC   = 1
      CALL XCOLI ( EKFILE,    HANDLE, SEGNO, COLUMN, NREC,
     .             VOXN(3),   NULLS,  NROWS                )
 
C
C     Read and store the voxel size in model units.
C
 
      COLUMN = 'VOXSIZ'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             SIZVOX, NULLS,  NROWS               )
 
C
C     Read and store the voxel grid origin in model units.
C
 
      COLUMN = 'VOXORI_X'
      NREC   = 1
      CALL XCOLD ( EKFILE,    HANDLE, SEGNO, COLUMN, NREC,
     .             ORIVOX(1), NULLS,  NROWS                )
 
      COLUMN = 'VOXORI_Y'
      NREC   = 1
      CALL XCOLD ( EKFILE,    HANDLE, SEGNO, COLUMN, NREC,
     .             ORIVOX(2), NULLS,  NROWS                )
 
      COLUMN = 'VOXORI_Z'
      NREC   = 1
      CALL XCOLD ( EKFILE,    HANDLE, SEGNO, COLUMN, NREC,
     .             ORIVOX(3), NULLS,  NROWS                )
 
C
C     Read and store the length of the array that holds pointers
C     into the voxel-plate occupation list.
C
 
      COLUMN = 'NVXTOT'
      NREC   = 1
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             TOTNVX, NULLS,  NROWS                )
 
C
C     Read and store the length of the array that holds
C     the voxel-plate occupation list.
C
      COLUMN = 'NVX'
      NREC   = 1
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             VXN,    NULLS,  NROWS                )
 
 
C
C     Read Segment Seven (VOXEL_POINTERS).
C
      SEGNO = 7
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the array that holds the pointers into
C     the voxel-plate occupancy list.
C
      COLUMN = 'VXPNTR'
      NREC   = TOTNVX
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             VXPNTR, NULLS,  NROWS                )
 
 
C
C     Read Segment Eight (VOXEL_LIST).
C
 
      SEGNO = 8
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the array that holds the pointers into
C     the voxel-plate occupancy list.
C
      COLUMN = 'VXLIST'
      NREC   = VXN
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             VXLIST, NULLS,  NROWS                )
 
 
C
C     Read Segment Nine (MASK).
C
 
      SEGNO = 9
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the array that contains the horizon mask.
C
 
      COLUMN = 'MASK'
      NREC   = NP
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             PMASK,  NULLS,  NROWS                )
 
      COLUMN = 'MAXELE'
      NREC   = NP
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             PMAXEL, NULLS,  NROWS                )
 
 
C
C     Read Segment Ten (COMMENTS).
C
 
      SEGNO = 10
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the array that contains the user-provided
C     comments.
C
 
      COLUMN = 'COMMENTS'
      NREC   = NLINE
      CALL XCOLC ( EKFILE,  HANDLE, SEGNO, COLUMN, NREC,
     .             COMMNT,  NULLS,  NROWS                )
 
 
 
C
C     Read Segment Eleven (VERTEX_POINTER).
C
      SEGNO = 11
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the array that holds the pointers into
C     the vertex-plate correspondence list.
C
      COLUMN = 'VCPNTR'
      NREC   = NV
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             VCPNTR, NULLS,  NROWS                )
 
 
C
C     Read Segment Twelve (VERTEX_SUMMARY).
C
      SEGNO = 12
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the length of the array that holds
C     the vertex-plate correspondence list.
C
      COLUMN = 'NVC'
      NREC   = 1
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             NVC,    NULLS,  NROWS                )
 
 
C
C     Read Segment Thirteen (VERTEX_COMMON).
C
      SEGNO = 13
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the array that holds the pointers into
C     the vertex-plate occupancy list.
C
      COLUMN = 'VCLIST'
      NREC   = NVC
      CALL XCOLI ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             VCLIST, NULLS,  NROWS                )
 
C
C     Read Segment Fourteen (MODEL_EXTENT).
C
      SEGNO = 14
 
      CALL SGNOTE ( HANDLE, SEGNO )
 
C
C     Read and store the model's X, Y, and Z minimum and
C     maximum extents.
C
      COLUMN = 'X_MIN'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             BXMIN,  NULLS,  NROWS               )
 
      COLUMN = 'X_MAX'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             BXMAX,  NULLS,  NROWS               )
 
      COLUMN = 'Y_MIN'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             BYMIN,  NULLS,  NROWS               )
 
      COLUMN = 'Y_MAX'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             BYMAX,  NULLS,  NROWS               )
 
      COLUMN = 'Z_MIN'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             BZMIN,  NULLS,  NROWS               )
 
      COLUMN = 'Z_MAX'
      NREC   = 1
      CALL XCOLD ( EKFILE, HANDLE, SEGNO, COLUMN, NREC,
     .             BZMAX,  NULLS,  NROWS               )
 
      BODEXT(1, 1, BINDEX) = BXMIN
      BODEXT(2, 1, BINDEX) = BXMAX
      BODEXT(1, 2, BINDEX) = BYMIN
      BODEXT(2, 2, BINDEX) = BYMAX
      BODEXT(1, 3, BINDEX) = BZMIN
      BODEXT(2, 3, BINDEX) = BZMAX
 
C
C     Generate and save the plate normals with area lengths.
C
 
      DO I = 1, NP
         K  = I + NPTOT
         DO J = 1, 3
            NORMAL(J,K) = NRMHAT(J,K) * AREA(I)
         END DO
      END DO

C
C     Update vertex and plate index boundry arrays and counts.
C     By index boundary we mean the indices values for the first
C     and last plate/vertex ID for a particular body if the
C     list of all plate/vertex IDs were stored in a single
C     array.
C
C     Given 2 loaded plates with a plate count of NP_1 and 
C     NP_2, an array containing all plate IDs has length
C     NP_1 + NP_2.
C
C        1         NP_1          NP_1 + NP_2
C        |...........|...............|
C
C     So  PBOUND(1,1) = 1        PBOUND(2,1) = NP_1
C         PBOUND(2,1) = NP_1 +1  PBOUND(2,2) = NP_1 + NP_2
C
C     Similarly for vertex IDs.
C
      VBOUND (1, BINDEX) =  1 + NVTOT
      VBOUND (2, BINDEX) = NV + NVTOT
  
      PBOUND (1, BINDEX) =  1 + NPTOT
      PBOUND (2, BINDEX) = NP + NPTOT
 
C
C     Update the total number of all vertices and plates
C     for all loaded bodies.
C
      NVTOT = NVTOT + NV
      NPTOT = NPTOT + NP
 
      CALL EKCLS( HANDLE )
      CALL CHKOUT ( 'INPLAT' )
 
      RETURN
 
 

 
C$Procedure  UNLDPL  ( Unload all plate models )
 
      ENTRY  UNLDPL
 
C$ Abstract
C
C     Reset total body, plate and vertex counters.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     unload plate models
C
C-&
 
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'UNLDPL' )
 
C
C     Zero out all count, body ID, and index 
C     values.
C 
      DO I = 1, NBTOT
         NAIFID(  I) = 0
         PBOUND(1,I) = 0
         PBOUND(2,I) = 0
         VBOUND(1,I) = 0
         VBOUND(2,I) = 0
      END DO
 
      NBTOT  = 0
      NPTOT  = 0
      NVTOT  = 0
  
      CALL CHKOUT ( 'UNLDPL' )
 
      RETURN
 
 
 

 
 
C$Procedure  NAM2DX  ( Name to body index )
 
      ENTRY  NAM2DX  ( BODNAM, BODEX )
 
C$ Abstract
C
C     Translate body name to body index.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODNAM     I   Body name.
C     BODEX      O   Body index number.
C
C
C$ Detailed_Input
C
C     BODNAM     Body name.
C
C$ Detailed_Output
C
C     BODEX      Body index number.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the input body name does not match a stored value,
C        the error 'SPICE(BODYNOTLOADED)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return body index given body name
C
C-&
 
C
C     Search over all loaded plate model body names,
C     ignoring blanks within the string.
C
 
      DO I = 1, NBTOT
         IF ( EQSTR( BODNAM, BDNAME(I) ) ) THEN
            BODEX = I
            RETURN
         END IF
      END DO
 
C
C     If plate model body was not found, activate standard
C     SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'NAM2DX' )
 
      CALL SETMSG ( 'Plate model body = # is not loaded.'  )
      CALL ERRCH  ( '#', BODNAM                            )
      CALL SIGERR ( 'SPICE(BODYNOTLOADED)'                 )
 
      CALL CHKOUT ( 'NAM2DX' )
 
      RETURN
 


 
C$Procedure  DX2NAM  ( Body index to name )
 
      ENTRY  DX2NAM  ( BODEX, BODNAM )
 
C$ Abstract
C
C     Given a body index, return its name.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index.
C     BODNAM     O   Body name.
C
C$ Detailed_Input
C
C     BODEX      Body index.
C
C$ Detailed_Output
C
C     BODNAM     Body name.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the input body index is out of range,
C        the error 'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return body name given body index
C
C-&
 
C
C     Verify that the body index is within range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'DX2NAM' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'DX2NAM' )
         RETURN
 
      END IF
 
C
C     Lookup body name.
C
 
      BODNAM = BDNAME ( BODEX )
 
      RETURN
 


 
C$Procedure  BID2DX  ( Body NAIF ID to index )
 
      ENTRY  BID2DX  ( NAFID, BODEX )
 
C$ Abstract
C
C     NAIF body ID to body index.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAFID      I   Body ID.
C     BODEX      O   Body index.
C
C$ Detailed_Input
C
C     NAFID      Body ID.
C
C$ Detailed_Output
C
C     BODEX      Body index.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the input body NAIF ID does not match a stored value,
C        the error 'SPICE(NAIFIDNOTLOADED)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate model body index given NAIF ID
C
C-&
 
C
C     Search saved array for NAIF ID.
C
 
      DO I = 1, NBTOT
         IF ( NAFID .EQ. NAIFID(I) ) THEN
            BODEX = I
            RETURN
         END IF
      END DO
 
C
C     If the requested NAIF ID is not loaded, activated
C     standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'BID2DX' )
 
      CALL SETMSG ( 'NAIF ID = # is not loaded.' )
      CALL ERRINT ( '#', NAFID                   )
      CALL SIGERR ( 'SPICE(NAIFIDNOTLOADED)'     )
 
      CALL CHKOUT ( 'BID2DX' )
 
      RETURN
 
 
 
 
 
 
 
 
C$Procedure  DX2BID  ( Body index to NAIF ID )
 
      ENTRY  DX2BID  ( BODEX, NAFID )
 
C$ Abstract
C
C     Translate body index to NAIF body ID.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     NAIF ID
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index.
C     NAFID      O   Body NAIF ID.
C
C$ Detailed_Input
C
C     BODEX      Body index.
C
C$ Detailed_Output
C
C     NAFID      Body NAIF ID.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return NAIF ID given body index
C
C-&
 
 
C
C     Verify that the body index is within range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'DX2BID' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'DX2BID' )
         RETURN
 
      END IF
 
C
C     Lookup NAIF ID.
C
 
      NAFID = NAIFID ( BODEX )
 
      RETURN
 
 


C--- Begin NTH routines

 
C$Procedure  NTHPLC  ( N'th plate center )
 
      ENTRY  NTHPLC  ( PLDEX, CENVEC )
 
C$ Abstract
C
C     Return the body-fixed coordinates of the center of
C     the N'th plate.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     CENVEC     O   Coordinates of plate center.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     CENVEC     Coordinates of plate center.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return plate center vector given plate index
C
C-&
 
 
C
C     Verify PLDEX is within limits; if not, activate
C     standard SPICE error handling.
C
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPLC' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPLC' )
         RETURN
 
      END IF
 
C
C     Lookup the coordinates of the plate's center.
C
 
      DO I = 1, 3
         CENVEC(I) = CENTER(I,PLDEX)
      END DO
 
      RETURN
 
 


 
 
C$Procedure  NTHPLN  ( N'th plate normal vector )
 
      ENTRY  NTHPLN  ( PLDEX, NRMVEC )
 
C$ Abstract
C
C     Return the body-fixed components for the outward pointing
C     normal vector of the N'th plate.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     NRMVEC     O   Plate normal vector.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     NRMVEC     Plate normal vector.
C
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate normal vector given plate index
C
C-&
 
 
 
C
C     Verify PLDEX is within limits; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPLN' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPLN' )
         RETURN
 
      END IF
 
C
C     Lookup the plate's normal vector.
C
 
      DO I = 1, 3
         NRMVEC(I) = NORMAL(I,PLDEX)
      END DO
 
      RETURN
 


 
 
C$Procedure NTHPLI ( N'th plate body index and plate ID )
 
      ENTRY NTHPLI ( PLDEX, BODEX, PLTID )
 
C$ Abstract
C
C     Return the body index and plate ID of the N'th plate.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MANAGER
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     BODEX      O   Body index.
C     PLTID      O   Plate ID.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     BODEX      Body index.
C     PLTID      Plate ID.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C     2) If the number of bodies is zero or less, the error
C        'SPICE(NOBODIESLOADED)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate ID and body index given plate index
C
C-&
 
 
 
C
C     Verify plate index is within range; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPLI' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPLI' )
         RETURN
 
      END IF
 
C
C     Get the body and plate indices.
C
 
      IF ( NBTOT .GT. 0 ) THEN
 
         DO I = 1, NBTOT
            IF ( (PLDEX .GE. PBOUND(1,I))     .AND.
     .           (PLDEX .LE. PBOUND(2,I))   )       THEN
               BODEX = I
               PLTID  = PLDEX - PBOUND(1,I) + 1
               RETURN
            END IF
         END DO
 
      END IF
 
C
C     Error tracing when no bodies are found.
C
 
      CALL CHKIN  ( 'NTHPLI' )
 
      CALL SETMSG ( 'No bodies loaded.'       )
      CALL SIGERR ( 'SPICE(NOBODIESLOADED)'   )
 
      CALL CHKOUT ( 'NTHPLI' )
 
      RETURN
 
 


 
 
C$Procedure  NTHVRI  ( N'th vertex ID and body index )
 
      ENTRY  NTHVRI  ( VRDEX, BODEX, VRTID )
 
C$ Abstract
C
C     Return the body index and vertex ID of the N'th vertex.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VRDEX      I   Vertex index.
C     BODEX      O   Body index.
C     VRTID      O   Vertex ID.
C
C$ Detailed_Input
C
C     VRDEX      Vertex index.
C
C$ Detailed_Output
C
C     BODEX      Body index.
C     VRTID      Vertex ID.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C     2) If the number of bodies is zero or less, the error
C        'SPICE(NOBODIESLOADED)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return body index and vertex ID given vertex index
C
C-&
 
C
C     Verify plate index is within range; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (VRDEX .LT. 1) .OR. (VRDEX .GT. NVTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHVRI' )
 
         CALL SETMSG ( 'Vertex index # is out of range' )
         CALL ERRINT ( '#', VRDEX                       )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'         )
 
         CALL CHKOUT ( 'NTHVRI' )
         RETURN
 
      END IF
 
C
C     Get the body and plate indices.
C
 
      IF ( NBTOT .GT. 0 ) THEN
 
         DO I = 1, NBTOT
            IF ( (VRDEX .GE. VBOUND(1,I))     .AND.
     .           (VRDEX .LE. VBOUND(2,I))   )       THEN
               BODEX = I
               VRTID  = VRDEX - VBOUND(1,I) + 1
               RETURN
            END IF
         END DO
 
      END IF
 
C
C
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'NTHVRI' )
 
      CALL SETMSG ( 'No bodies loaded.'       )
      CALL SIGERR ( 'SPICE(NOBODIESLOADED)'   )
 
      CALL CHKOUT ( 'NTHVRI' )
 
      RETURN
 
 


 
 
C$Procedure  NTHPLV  ( N'th plate vertices )
 
      ENTRY  NTHPLV  ( PLDEX, VINPLT )
 
C$ Abstract
C
C     Return the body-fixed coordinates of the N'th plate's
C     three vertices.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     VINPLT     O   Vertex coordinates.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     VINPLT     Vertex coordinates.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return coordinates of plate vertices
C
C-&
 
C
C     Verify that the plate index is within limits; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPLV' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPLV' )
         RETURN
 
      END IF
 
C
C     Look up the coordinates of the plate's three vertices.
C
 
      DO I = 1, 3
         VRDEX2 = VLIST(I,PLDEX)
         DO J = 1, 3
            VINPLT(J,I) = VRTXYZ(J,VRDEX2)
         END DO
      END DO
 
      RETURN
 
 


 
 
C$Procedure  NTHPVL  ( N'th plate ID and vertex list )
 
      ENTRY  NTHPVL  ( PLDEX, PLTID, VLOUT )
 
C$ Abstract
C
C     Given the plate index return the
C     list of vertex indices that belong to it.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index value.
C     PLTID      O   Plate ID number.
C     VLOUT      O   List of vertex indices that belong to plate.
C
C$ Detailed_Input
C
C     PLDEX      Plate index value.
C
C$ Detailed_Output
C
C     PLTID      Plate ID number.
C     VLOUT      List if vertex indices that belong to plate.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return a plate's vertex ID's
C
C-&
 
C
C     Verify that the plate index is in range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPVL' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPVL' )
         RETURN
 
      END IF
 
C
C     Lookup the plate ID and vertex indices.
C
 
      PLTID = PID( PLDEX )
 
      DO I = 1, 3
         VLOUT(I) = VLIST( I, PLDEX )
      END DO
 
      RETURN




 
 
C$Procedure  NTHVRT  ( N'th vertex ID and coordinates )
 
      ENTRY  NTHVRT  ( VRDEX, VRTID, VOUT )
 
C$ Abstract
C
C     Return the N'th vertex's ID number and its body-fixed coordinates.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VRDEX      I   Vertex index number.
C     VRTID      O   Vertex ID number.
C     VOUT       O   Vertex coordinates.
C
C
C$ Detailed_Input
C
C     VRDEX      N'th vertex's index number.
C
C$ Detailed_Output
C
C     VRTID      N'th vertex's ID number.
C     VOUT       Body-fixed coordinates of the N'th vertex.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the vertex index is out of range , the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return plate model vertex ID and coordinates given vertex index
C
C-&
 
 
C
C     Verify that the vertex index is in range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (VRDEX .LT. 1) .OR. (VRDEX .GT. NVTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHVRT' )
 
         CALL SETMSG ( 'Vertex index # is out of bounds' )
         CALL ERRINT ( '#', VRDEX                        )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'          )
 
         CALL CHKOUT ( 'NTHVRT' )
         RETURN
 
      END IF
 
C
C     Obtain the vertex's ID number.
C
 
      VRTID = VID ( VRDEX )
 
C
C     Obtain body-fixed coordinates for the N'th vertex.
C
      DO I = 1, 3
         VOUT(I) = VRTXYZ(I,VRDEX)
      END DO
 
      RETURN
 
 


 
 
C$Procedure  NTHALB  ( N'th plate albedo )
 
      ENTRY  NTHALB  ( PLDEX, PLTID, ALBOUT )
 
C$ Abstract
C
C     Return the N'th plate's ID value and its albedo.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate's index number.
C     PLTID      O   Plate's ID value.
C     ALBOUT     O   Plate's albedo.
C
C
C$ Detailed_Input
C
C     PLDEX      Plate's index number.
C
C
C$ Detailed_Output
C
C     PLTID      Plate's ID number.
C     ALBOUT     Plate's albedo value.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range , the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C       return plate ID and plate albedo given plate index
C
C-&
 
 
C
C     Verify that the plate index is in range; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN  ( 'NTHALB' )
 
         CALL SETMSG ( 'Plate index # is out of bounds'  )
         CALL ERRINT ( '#', PLDEX                        )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'          )
 
         CALL CHKOUT ( 'NTHALB' )
         RETURN
 
      END IF
 
C
C     Obtain the Plate's ID number.
C
 
      PLTID = PID ( PLDEX )
 
C
C     Obtain the albedo for the N'th plate.
C
 
      ALBOUT = ALBEDO( PLDEX )
 
      RETURN




 
 
C$Procedure  NTHPLA  ( N'th plate area )
 
      ENTRY  NTHPLA  ( PLDEX, PLAREA )
 
C$ Abstract
C
C     Return the area of the N'th plate.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     NRMVEC     O   Plate area.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     AREA       Plate area.
C
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-OCT-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate area given plate index
C
C-&
 
 
 
C
C     Verify PLDEX is within limits; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPLA' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPLA' )
         RETURN
 
      END IF
 
C
C     Lookup the plate's normal vector.
C
 
      PLAREA = AREA(PLDEX)
 
      RETURN
 
 
C
C     NTHPUN  
C
 
 
C$Procedure  NTHPUN  ( N'th plate unit normal vector )
 
      ENTRY  NTHPUN  ( PLDEX, NRMUN )
 
C$ Abstract
C
C     Return the body-fixed components for the outward pointing
C     unit normal vector of the N'th plate.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     NRMUN      O   Plate unit normal vector.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     NRMUN      Plate unit normal vector.
C
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-OCT-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate unit normal vector given plate index
C
C-&
 
 
 
C
C     Verify PLDEX is within limits; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHPUN' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHPUN' )
         RETURN
 
      END IF
 
C
C     Lookup the plate's normal vector.
C
 
      DO I = 1, 3
         NRMUN(I) = NRMHAT(I,PLDEX)
      END DO
 
      RETURN
 

 
 
C$Procedure  NTHSID  ( N'th plate's longest side length )
 
      ENTRY  NTHSID  ( PLDEX, LNGSID )
 
C$ Abstract
C
C     Return the N'th plate's longest side's length.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     LNGSID     O   Plate longest side's length.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     LNGSID     Plate longest side's length.
C
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-OCT-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate's longest side's length given the plate index
C
C-&
 
 
 
C
C     Verify PLDEX is within limits; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHSID' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHSID' )
         RETURN
 
      END IF
 
C
C     Lookup the plate's longest side's length.
C
 
      LNGSID = LSIDE(PLDEX)
 
      RETURN
 
 
C
C     NTHMSK  
C
 
 
C$Procedure  NTHMSK  ( N'th plate's horizon mask parameters )
 
      ENTRY  NTHMSK  ( PLDEX, MSKFLG, MAXELE )
 
C$ Abstract
C
C     Return the N'th plate's mask parameters.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLDEX      I   Plate index.
C     MSKFLG     O   Plate mask flag.
C     MAXELE     O   Maximum elevation of all obstruction on the
C                    plate's horizon.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C$ Detailed_Output
C
C     MSKFLG     Plate mask flag.
C     MAXELE     Maximum elevation of all obstructions on the
C                plate's horizon.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the plate index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 23-MAR-1999 (JAB)
C
C        Added MAXELE parameter.
C
C-    SPICELIB Version 1.0.0, 28-OCT-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate's horizon mask parameters.
C
C-&
 
 
 
C
C     Verify PLDEX is within limits; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (PLDEX .LT. 1) .OR. (PLDEX .GT. NPTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'NTHMSK' )
 
         CALL SETMSG ( 'Plate index # is out of range' )
         CALL ERRINT ( '#', PLDEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'NTHMSK' )
         RETURN
 
      END IF
 
C
C     Lookup the plate's mask parameters.
C
 
      MSKFLG = PMASK(PLDEX)
      MAXELE = PMAXEL(PLDEX)
 
      RETURN
 


C--- End NTH routines

 
 
C$Procedure  PLTIDX  ( Plate ID and body index to plate index )
 
      ENTRY  PLTIDX  ( PLTID, BODEX, PLDEX )
 
C$ Abstract
C
C     Return the index of a plate given a plate ID
C     and body index.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLTID      I   Plate ID.
C     BODEX      I   Body index.
C     PLDEX      O   Plate index.
C
C$ Detailed_Input
C
C     PLTID      Plate ID.
C     BODEX      Body index.
C
C$ Detailed_Output
C
C     PLDEX      Plate index.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C     2) If the plate ID is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate index given plate ID and body index
C
C-&
 
 
C
C     Verify that the body index is within range.
C     If not, perform standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'PLTIDX' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'PLTIDX' )
         RETURN
 
      END IF
 
C
C     Verify that plate ID is in range for the given body.
C     If not, perform standard SPICE error handling.
C
C     NPLTS(BODEX) is the total number of plates
C     associated with body NBTOT.
C
 
      IF ( (PLTID .LT. 1) .OR. (PLTID .GT. NPLTS(BODEX)) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'PLTIDX' )
 
         CALL SETMSG (    'Plate ID # is out of range '
     .                 // 'for body index #           ')
         CALL ERRINT ( '#', PLTID                      )
         CALL ERRINT ( '#', BODEX                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'PLTIDX' )
         RETURN
 
      END IF
 
C
C     Look up the index of the first plate belonging
C     to body BODEX and construct the plate index.
C
 
      PLDEX = PBOUND(1,BODEX) + PLTID - 1
 
      RETURN
 
 
 
 
C$Procedure  VRTIDX  ( vertex ID and body index to vertex index )
 
      ENTRY  VRTIDX  ( VRTID, BODEX, VRDEX )
 
C$ Abstract
C
C     Given a vertex ID and body index, return the vertex index.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VRTID      I   Vertex ID.
C     BODEX      I   Body index.
C     VRDEX      O   Vertex index.
C
C$ Detailed_Input
C
C     VRTID      Vertex ID.
C     BODEX      Body index.
C
C$ Detailed_Output
C
C     VRDEX      Vertex index.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C     2) If the vertex ID is out of range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return vertex index given vertex ID and body index
C
C-&
 
C
C     Verify that the body index is within range;
C     if not, activate standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'VRTIDX' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'VRTIDX' )
         RETURN
 
      END IF
 
C
C     Verify that vertex ID is in range for the given body.
C     If not, perform standard SPICE error handling.
C
C     NVRTS(BODEX) is the total number of vertices
C     associated with body NBTOT.
C
 
      IF ( (VRTID .LT. 1) .OR. (VRTID .GT. NVRTS(BODEX)) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'VRTIDX' )
 
         CALL SETMSG (    'Vertex ID # is out of range '
     .                 // 'for body index #            ')
         CALL ERRINT ( '#', VRTID                       )
         CALL ERRINT ( '#', BODEX                       )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'         )
 
         CALL CHKOUT ( 'VRTIDX' )
         RETURN
 
      END IF
 
C
C     Look up the index of the first vertex belonging
C     to body BODEX and construct the vertex index.
C
 
      VRDEX = VBOUND(1,BODEX) + VRTID - 1
 
      RETURN
 
 


 
 
C$Procedure  VRTEDG  ( Vertices connected to a vertex by edges )
 
      ENTRY  VRTEDG  ( VRDEX, NVSET, EDGVRT )
 
C$ Abstract
C
C     Return the indices of all vertices connected to a
C     given one by an edge.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VRDEX      I   Vertex index number.
C     NVSET      O   Number of vertices connected to VRDEX by an edge.
C     EDGVRT     O   List of NVSET vertices connected to VRDEX by an
C                    edge.
C
C$ Detailed_Input
C
C     VRDEX      Vertex index number.
C
C$ Detailed_Output
C
C     NVSET      Number of vertices that are connected to the vertex
C                VRDEX by an edge.
C     EDGVRT     An array containing the NVSET vertex indices that are
C                connected to VRDEX by an edge.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the vertex index is out of range , the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997, (JAB)
C
C-&
 
C$ Index_Entries
C
C     return list of vertex indices connected to a given vertex by
C     an edge
C-&
 
 
C
C     If VRDEX is out of range, activate standard SPICE
C     error handling.
C
 
      IF ( (VRDEX .LT. 1) .OR. (VRDEX .GT. NVTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'VRTEDG' )
 
         CALL SETMSG ( 'Vertex index # is not in the range'   //
     .                 ' (1 to #).'                     )
         CALL ERRINT ( '#', VRDEX                       )
         CALL ERRINT ( '#', NVTOT                       )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'         )
 
         CALL CHKOUT ( 'VRTEDG' )
         RETURN
 
      END IF
 
C
C     Get the list of plates containing vertex VRDEX.
C
 
      PLTPTR  = VCPNTR(VRDEX)
 
      IF( PLTPTR .NE. -1 ) THEN
 
         NUMPLT = VCLIST( PLTPTR )
 
         DO I = 1, NUMPLT
            PVLIST(I) = VCLIST( PLTPTR + I )
         END DO
 
      ELSE
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'VRTEDG' )
 
         CALL SETMSG ( 'Null Pointer at VRDEX =  #'     )
         CALL ERRINT ( '#', VRDEX                       )
         CALL SIGERR ( 'SPICE(NULLPOINTER)'             )
 
         CALL CHKOUT ( 'VRTEDG' )
         RETURN
 
      END IF
 
 
C
C     Create a set of vertices from the plates shared by VRDEX.
C
 
      CALL VALIDI ( MAXEDG, 0, VRTSET )
 
      DO I = 1, NPLT
         NEWPLT = PVLIST(I)
         DO J = 1, 3
            NEWVRT = VLIST(J,NEWPLT)
            IF ( NEWVRT .NE. VRDEX ) THEN
                CALL INSRTI ( NEWVRT, VRTSET )
            END IF
         END DO
      END DO
 
C
C     Place the vertex set into an array.
C
 
      NVSET = CARDI ( VRTSET )
 
      DO I = 1, NVSET
         EDGVRT(I) = VRTSET(FETCHI(I,VRTSET))
      END DO
 
 
      RETURN
 


 
 
C$Procedure  VRTPLT  ( Plates shared by a vertex )
 
      ENTRY  VRTPLT  ( VRDEX, NUMPLT, PLATES )
 
C$ Abstract
C
C     Return the indices of plates that share a given vertex.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VRDEX      I   Vertex index number.
C     NUMPLT     O   Number of plates that share the vertex VRDEX.
C     PLATES     O   List of NUMPLT plates that shares the vertex VRDEX.
C
C$ Detailed_Input
C
C     VRDEX      Vertex index number.
C
C$ Detailed_Output
C
C     NUMPLT     Number of plates that share the vertex VRDEX.
C     PLATES     An array containing the plate indices of those
C                plates that share the vertex VRDEX.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the vertex index is out of range , the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997, (JAB)
C
C-&
 
C$ Index_Entries
C
C     return list of plate ID's that contain a given vertex
C-&
 
 
C
C     If VRDEX is out of range, activate standard SPICE
C     error handling.
C
 
      IF ( (VRDEX .LT. 1) .OR. (VRDEX .GT. NVTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'VRTPLT' )
 
         CALL SETMSG ( 'Vertex index # is out of range' )
         CALL ERRINT ( '#', VRDEX                       )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'         )
 
         CALL CHKOUT ( 'VRTPLT' )
         RETURN
 
      END IF
 
C
C     Lookup plate and vertex information from stored arrays.
C
 
      PLTPTR  = VCPNTR(VRDEX)
 
      IF( PLTPTR .NE. -1 ) THEN
 
         NUMPLT = VCLIST( PLTPTR )
 
         DO I = 1, NUMPLT
            PLATES(I) = VCLIST( PLTPTR + I )
         END DO
 
      ELSE
 
         IF ( RETURN() ) THEN
            RETURN
         END IF
 
         CALL CHKIN ( 'VRTPLT' )
 
         CALL SETMSG ( 'Null Pointer at VRDEX =  #'     )
         CALL ERRINT ( '#', VRDEX                       )
         CALL SIGERR ( 'SPICE(NULLPOINTER)'             )
 
         CALL CHKOUT ( 'VRTPLT' )
         RETURN
 
      END IF
 
      RETURN
 
 


 
 
C$Procedure  PLSIZE  ( Plate model array sizes )
 
      ENTRY  PLSIZE  ( NBTOTL, NPTOTL, NVTOTL,  NAFIDS,
     .                 NPLATS, PLBNDS, NVERTS,  VRBNDS    )
 
C$ Abstract
C
C     Given a body index, return the number of plates
C     and vertices and the storage location bounds of
C     that body's plates and vertices.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NBTOTL     O   Total number of plate model bodies loaded.
C     NPTOTL     O   Total number of plates loaded.
C     NVTOTL     O   Total number of vertices loaded.
C     NAFIDS     O   NAIF ID of each loaded body.
C     NPLATS     O   Number of plates in plate model.
C     PLBNDS     O   Plate storage location bounds.
C     NVERTS     O   Number of vertices in plate model.
C     VRBNDS     O   Vertex storage location bounds.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     NBTOTL     Total number of different plate model bodies loaded.
C     NPTOTL     Total number of plates loaded, over all plate models.
C     NVTOTL     Total number of vertices loaded, over all plate models.
C     NAFIDS     NAIF ID's of all plate model bodies.
C     NPLATS     Number of plates in each plate model.
C     PLBNDS     The start and end storage indices of plates for each
C                plate model.
C     NVERTS     Number of vertices in each plate model.
C     VRBNDS     The start and end storage indices of vertices for each
C                plate model.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return all plate and vertex storage array boundry locations
C
C-&
 
C$ Revisions
C
C-&
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'PLSIZE' )
 
      NBTOTL = NBTOT
      NPTOTL = NPTOT
      NVTOTL = NVTOT
 
      DO I = 1, NBTOT
         NAFIDS (  I) = NAIFID(I)
         NPLATS (  I) = PBOUND(2,I) - PBOUND(1,I) + 1
         NVERTS (  I) = VBOUND(2,I) - VBOUND(1,I) + 1
         PLBNDS (1,I) = PBOUND(1,I)
         PLBNDS (2,I) = PBOUND(2,I)
         VRBNDS (1,I) = VBOUND(1,I)
         VRBNDS (2,I) = VBOUND(2,I)
      END DO
 
      CALL CHKOUT ( 'PLSIZE' )
 
      RETURN
 
 


 
 
C$Procedure  PLTBND  ( Plate model storage map bounds)
 
      ENTRY  PLTBND  ( BODEX, NPLT, PLBND, NVRT, VRBND )
 
C$ Abstract
C
C     Given a body index, return the number of plates
C     and vertices and the storage location bounds of
C     that plate model body's plates and vertices.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index number.
C     NPLT       O   Number of plates in plate model.
C     PLBND      O   Plate storage location bounds.
C     NVRT       O   Number of vertices in plate model.
C     VRBND      O   Vertex storage location bounds.
C
C$ Detailed_Input
C
C     BODEX      Body index number
C
C$ Detailed_Output
C
C     NPLT       Number of plates belonging to the requested body.
C
C     PLBND      The start and end indices in the plate index array.
C
C     NVRT       Number of vertices belonging to the requested body.
C
C     VRBND      The start and end indices in the vertex index array.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is not in range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return a body's plate and vertex array storage boundry locations
C
C-&
 
C$ Revisions
C
C-&
 
C
C     Verify that the body index is within range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
           RETURN
         END IF
 
         CALL CHKIN ( 'PLTBND' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'PLTBND' )
         RETURN
 
      END IF
 
C
C     Lookup plate and vertex boundry locations.
C
 
      PLBND(1) = PBOUND( 1, BODEX )
      PLBND(2) = PBOUND( 2, BODEX )
      NPLT     = PLBND(2) - PLBND(1) + 1
 
      VRBND(1) = VBOUND( 1, BODEX )
      VRBND(2) = VBOUND( 2, BODEX )
      NVRT     = VRBND(2) - VRBND(1) + 1
 
      RETURN
 
 


 
 
C$Procedure  PLTOT  ( Plate model totals)
 
      ENTRY  PLTOT  ( NBTOTL, NPTOTL, NVTOTL )
 
C$ Abstract
C
C     Return plate model body, plate and vertex totals.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NBTOTL     O   Total number of bodies loaded.
C     NPTOTL     O   Total number of plates loaded.
C     NVTOTL     O   Total number of vertices loaded.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     NBTOTL     Total number of different plate models loaded.
C     NPTOTL     Total number of plates loaded, over all plate models.
C     NVTOTL     Total number of vertices loaded, over all plate models.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return plate model body, plate and vertex totals
C
C-&
 
C$ Revisions
C
C-&
 
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'PLTOT' )
 
      NBTOTL = NBTOT
      NPTOTL = NPTOT
      NVTOTL = NVTOT
 
      CALL CHKOUT ( 'PLTOT' )
 
      RETURN
 
 


 
 
C$Procedure  PLHEAD  ( Plate model kernel header information  )
 
      ENTRY  PLHEAD  ( BODEX,  DESCR,  CRTOR, CRDAT, BODNAM,
     .                 NAFID,  VERS,   NPLT,  NVRT            )
 
C$ Abstract
C
C     Given a body index, return plate model information from the kernel
C     header table.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     MKPLAT
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index number.
C     DESCR      O   Description of plate model kernel.
C     CRTOR      O   Name of plate model creator.
C     CRDAT      O   Plate model creation date.
C     BODNAM     O   Name of plate model body.
C     NAFID      O   Plate model body's NAIF ID.
C     VERS       O   Plate model version number.
C     NPLT       O   Number of plates in model.
C     NVRT       O   Number of vertices in model.
C
C$ Detailed_Input
C
C     BODEX      Body index number
C
C$ Detailed_Output
C
C     DESCR      Text string description of the plate model kernel
C                referred to by the body index, BODEX.
C     CRTOR      Text name of the plate model's creator.
C     CRDAT      Creation time and date stamp.
C     BODNAM     Name of the body corresponding to BODEX.
C     NAFID      NAIF ID number of the body.
C     VERS       Version number of the plate model, an integer.
C     NPLT       Number of plates belonging to body.
C     NVRT       Number of vertices belonging to body.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is not in range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 19-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return plate model header information
C
C-&
 
C$ Revisions
C
C-&
 
 
C
C     Verify that the body index is in range; if not, activate
C     standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
            RETURN
          END IF
 
         CALL CHKIN  ( 'PLHEAD' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'PLHEAD' )
         RETURN
 
      END IF
 
C
C     Lookup plate model header information from saved arrays.
C
 
      DESCR  = MODESC ( BODEX )
      CRTOR  = CREATR ( BODEX )
      CRDAT  = CRDATE ( BODEX )
      BODNAM = BDNAME ( BODEX )
      NAFID  = NAIFID ( BODEX )
      VERS   = IVER   ( BODEX )
      NPLT   = NPLTS  ( BODEX )
      NVRT   = NVRTS  ( BODEX )
 
      RETURN
 
 

 
C$Procedure   BEXTNT  ( body size extents )
 
      ENTRY   BEXTNT  ( BODEX, BMIN, BMAX )
 
C$ Abstract
C
C     Given a body index, return its min/max extents in x, y and z.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index.
C     BMIN       O   Vector of minimum body extent coords.
C     BMAX       O   Vector of maximum body extent coords.
C
C$ Detailed_Input
C
C     BODEX      Body index.
C
C
C$ Detailed_Output
C
C     BMIN       a 3-vector containing the minimum body extent 
C                coordinates for x, y and z.
C
C     BMAX       a 3-vector containing the maximum body extent
C                coordinates for x, y and z.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is not in range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 2.0.0, 10-SEP-2004 (JAB)
C
C        Reimplemented routine with two output 3-vectors
C        BMIN and BMAX replacing the output 2X3 matrix.
C
C-    SPICELIB Version 1.0.0, 21-AUG-1997 (JAB)
C
C-&
 
C$ Index_Entries
C
C     return body extents given body index
C
C-&
 
C
C     Verify that the body index is within range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
           RETURN
         END IF
 
         CALL CHKIN ( 'BEXTNT' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'BEXTNT' )
         RETURN
 
      END IF
 
C
C     Lookup body extent.
C
 
      BMIN(1) = BODEXT(1, 1, BODEX)
      BMIN(2) = BODEXT(1, 2, BODEX)
      BMIN(3) = BODEXT(1, 3, BODEX)

      BMAX(1) = BODEXT(2, 1, BODEX)
      BMAX(2) = BODEXT(2, 2, BODEX)
      BMAX(3) = BODEXT(2, 3, BODEX)
 
      RETURN
 
  
 
C$Procedure   KERCOM  ( plate kernel comments )
 
      ENTRY   KERCOM  ( BODEX, NCOM, COMS )
 
C$ Abstract
C
C     Given a body index, return the number of comments lines
C     and comments themselves.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index.
C     NCOM       O   Number of comment lines.
C     COMS       O   Comment lines.
C
C
C$ Detailed_Input
C
C     BODEX      Body index.
C
C
C$ Detailed_Output
C
C     NCOM       Number of comment lines.
C     COMS       Comment line array.
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is not in range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-OCT-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return plate kernel comments
C
C-&
 
C
C     Verify that the body index is within range; if not,
C     activate standard SPICE error handling.
C
 
      IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN
 
         IF ( RETURN() ) THEN
           RETURN
         END IF
 
         CALL CHKIN ( 'KERCOM' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'KERCOM' )
         RETURN
 
      END IF
 
C
C     Transfer comment lines to output array.
C
      NCOM = NLINE
 
      DO I = 1, NCOM
         COMS(I) = COMMNT(I)
      END DO
 
      RETURN
 

 
 
C$Procedure   VOXSUM  ( spatial index summary parameters )
 
      ENTRY   VOXSUM  ( BODEX, NVOX, VOXSIZ, VOXORI, NVXTOT, NVX )
 
C$ Abstract
C
C     Given a body index, return the spatial index parameters
C     related to the voxel grid.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     BODEX      I   Body index.
C     NVOX       O   Number of voxels in each dimension.
C     VOXSIZ     O   Size of voxel in model units.
C     VOXORI     O   Origin of voxel grid in model units.
C     NVXTOT     O   Total number of voxels.
C     NVX        O   Length of voxel-plate occupation array.
C
C$ Detailed_Input
C
C     BODEX      Body index.
C
C
C$ Detailed_Output
C
C     TBD
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is not in range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-OCT-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return spatial index parameters
C
C-&
 
C
C     Verify that the body index is within range; if not,
C     activate standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
         
       IF ( (BODEX .LT. 1) .OR. (BODEX .GT. NBTOT) ) THEN

         CALL CHKIN ( 'VOXSUM' )
 
         CALL SETMSG ( 'Body index # is out of range' )
         CALL ERRINT ( '#', BODEX                     )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'       )
 
         CALL CHKOUT ( 'VOXSUM' )
         RETURN
 
      END IF
 
C
C     Transfer voxel grid parameters to output variables.
C
      DO I = 1, 3
         NVOX(I)   = VOXN(I)
         VOXORI(I) = ORIVOX(I)
      END DO
 
      VOXSIZ = SIZVOX
      NVXTOT = TOTNVX
      NVX    = VXN
 
      RETURN
 
 

 
 
C$Procedure   VOXPLT  ( return list of plates occupying a voxel )
 
      ENTRY   VOXPLT  ( VOXID, NPINVX, PVXLST )
 
C$ Abstract
C
C     Given a voxel ID, return a list of plate IDs that occupy it.
C
C$ Copyright
C
C     Copyright (1998), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
C
C     See: $Declarations for PLTMGR.
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C
C     VOXID      I   Voxel ID.
C     NPINVX     O   Number of plates occupying the voxel.
C     PVXLST     O   List of plate IDs in the voxel.
C
C$ Detailed_Input
C
C     BODEX      Body index.
C
C
C$ Detailed_Output
C
C     TBD
C
C$ Parameters
C
C     See: $Parameters for PLTMGR.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If the body index is not in range, the error
C        'SPICE(INDEXOUTOFRANGE)' is signaled.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) A plate model must be loaded by INPLAT and currently
C        resident in memory before this routine is called.
C
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 06-DEC-1998 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     return spatial index parameters
C
C-&
 
C
C     Verify that the voxel index is within range; if not,
C     activate standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
         
      IF ( (VOXID .LT. 1) .OR. (VOXID .GT. TOTNVX) ) THEN
 
         CALL CHKIN ( 'VOXPLT' )
 
         CALL SETMSG ( 'Voxel index # is out of range' )
         CALL ERRINT ( '#', VOXID                      )
         CALL SIGERR ( 'SPICE(INDEXOUTOFRANGE)'        )
 
         CALL CHKOUT ( 'VOXPLT' )
         RETURN
 
      END IF
 
C
C     VOXPTR is a pointer into the plate list.
C
 
      VOXPTR  = VXPNTR(VOXID)
 
      IF( VOXPTR .NE. -1 ) THEN

C
C        First value of the plate list is the plate
C        count.
C
         NPINVX = VXLIST( VOXPTR )

C
C        The list of plate IDs follow.
C
         DO I = 1, NPINVX
            PVXLST(I) = VXLIST( VOXPTR + I )
         END DO
 
      ELSE

C
C        Voxel is empty, return zero for the number of plates.
C
         NPINVX = 0
 
      END IF

      RETURN


      END
