C$Procedure  PLTNBR  ( given a plate ID return its neighbors )
 
      SUBROUTINE PLTNBR ( PLTID, NBRIDS )
 
C$ Abstract
C
C     Given a plate ID, return the IDs of the three plates
C     that neighbor it.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               PLTID
      INTEGER               NBRIDS   ( * )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PLTID      I   Plate ID.
C
C     NBRIDS     O   List of three plate IDs that are neighbors to
C                    PLTID.
C
C$ Detailed_Input
C
C     PLTID          plate ID.
C
C$ Detailed_Output
C
C     NBRIDS         list of three plate IDs that are neighbors to
C                    PLTID.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Later.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 26-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C      find neighbors of a given plate
C
C-&
 
      INCLUDE              'pltmax.inc'
 
      INTEGER               I
      INTEGER               J
      INTEGER               NP
      INTEGER               NV
      INTEGER               NB
      INTEGER               NP2
      INTEGER               NPLT
      INTEGER               VLOUT   ( 3 )
      INTEGER               PLTLST  ( MAXEDG )
      INTEGER               PCOUNT  ( MAXPLT )
 
 
      NP2 = 0
 
 
C
C     What vertices belong to the plate?
C
 
      CALL NTHPVL ( PLTID, PLTID, VLOUT )
 
C
C     What is the number of plates in the model.
C
 
      CALL PLTOT ( NB, NP, NV )
 
C
C     Initialize plate counts.
C
 
      DO I = 1, NP
         PCOUNT(I) = 0
      END DO
 
C
C     For each vertex, get the list of plates it belongs to.
C
 
      DO I = 1, 3
         CALL VRTPLT ( VLOUT(I), NPLT, PLTLST )
         DO J = 1, NPLT
            PCOUNT(PLTLST(J)) = PCOUNT(PLTLST(J)) + 1
         END DO
      END DO
 
C
C     Determine which plates have two vertices in common.
C
 
      DO I = 1, NP
         IF ( PCOUNT(I) .EQ. 2 ) THEN
            NP2 = NP2 + 1
            NBRIDS(NP2) = I
         END IF
      END DO
 
      RETURN
      END
