C$Procedure      PTHDIM ( Path dimension )
 
      INTEGER FUNCTION PTHDIM ( PATHS )
 
C$ Abstract
C
C     Return the dimension of the points stored in a path list
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      PATHS
C
C$ Declarations
 
      IMPLICIT NONE
      INTEGER               LBPOOL
      PARAMETER           ( LBPOOL = -5 )
 
      INTEGER               PATHS  ( 2, LBPOOL:* )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PATHS      I  is the linked list component of an initialized list
C
C     The function returns the dimension of points in the path list.
C
C$ Detailed_Input
C
C     PATHS      is the linked list portion an initialized path list
C                that holds the node values paths.
C
C$ Detailed_Output
C
C     The function returns the dimension of the points stored in
C     a path list.
C
C$ Parameters
C
C     LBPOOL     is the lower bound used in the linked list software.
C                It must have the value -5.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This is a utility program that allows various components
C     of a user's program to determine the dimension associated
C     with the points in a path list.
C
C$ Examples
C
C     Suppose you want to write a general purpose routine that
C     determines the longest edge of a path.  To do this you
C     need to know the dimension of the points in the path.
C
C     Here's how you might go about writing such a function
C     The call to PTHDIM is highlighted by angle brackets <<<  >>>
C
C        DOUBLE PRECISION  FUNCTION PTHMAX ( HEAD, PATHS, VERTXS )
C
C        INTEGER               HEAD
C        INTEGER               PATHS  ( LBPOOL : * )
C        DOUBLE PRECISION      VERTXS ( * )
C
C
C        SPICELIB Functions
C
C        DOUBLE PRECISION      VDISTG
C        INTEGER               PTHDIM
C        INTEGER               LNKNXT
C
C        In-line functions
C
C        INTEGER               AT
C
C
C        Local Variables
C
C        DOUBLE PRECISION      LNGEST
C        INTEGER               NEXT
C        INTEGER               DIM
C
C
C        In line function definition
C
C        AT(NODE) = ( NODE - 1 ) * DIM + 1
C
C        Get the dimension of the paths.
C
C   <<< DIM    = PTHDIM ( PATHS )  >>>
C
C
C        Now compute the longest segment
C
C        LNGEST = 0.0D0
C        THIS   = HEAD
C        NEXT   = LNKNXT( THIS, HEAD )
C
C        DO WHILE ( NEXT .GT. 0 )
C
C           L      = VDISTG ( VERTXS( AT(THIS) ), ...
C                             VERTXS( AT(NEXT) ), DIM )
C           LNGEST = MAX( L, LNGEST )
C
C           THIS   = NEXT
C           NEXT   = LNKNXT ( THIS, PATHS )
C
C        END DO
C
C        PTHMAX = LNGEST
C        RETURN
C
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 2.0.0, 02-FEB-1999 (JAB)
C
C          Removed unneeded declaration and parameter statements.
C
C-    SPICELIB Version 1.0.0, 03-APR-1997 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     Get the dimension associated with a path list
C
C-&
C
C     Parameters
C
 
C
C     The control area of PATHS contains 3 elements.  They are:
C
C        The "size" of the pool, that is, the number
C        of nodes in the pool.
C
C        The number of free nodes in the pool.
C
C        The "free pointer," which is the column index of the first free
C        node.
C
C     Parameters defining the row and column indices of these control
C     elements are given below.
C
      INTEGER               SIZROW
      PARAMETER           ( SIZROW =   1 )
 
      INTEGER               SIZCOL
      PARAMETER           ( SIZCOL =   0 )
 
 
C
C     The rows of the path list dimension and path count are given
C     below.  The columns must be computed from values stored in
C     the array PATHS.
C
      INTEGER               DIMROW
      PARAMETER           ( DIMROW = 1 )
 
 
C
C     Local Variables
C
      INTEGER               SIZE
      INTEGER               DIMCOL
 
 
C
C     First determine the size of the path list.
C
      SIZE   = PATHS(SIZROW,SIZCOL)
C
C     Compute the column in PATHS where the dimension and number
C     of paths is stored.
C
      DIMCOL = SIZE + 1
 
      PTHDIM = PATHS(DIMROW,DIMCOL)
 
      RETURN
      END
