C$Procedure    SGNOTE   ( output name of an e-kernel segment )
 
      SUBROUTINE SGNOTE ( HANDLE, SEGNO )
 
C$ Abstract
C
C     Output to screen data about a particular E-kernel segment.
C     In this incarnation, it prints to standard output
C     the segment number and name.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     E-KERNEL
C
C$ Declarations
 
      IMPLICIT NONE
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     HANDLE     I   E-kernel handle number.
C
C     SEGNO      I   Segment number.
C
C$ Detailed_Input
C
C     HANDLE     E-kernel handle number, determined by EKOPR.
C
C     SEGNO      Segment number you want the name of.
C
C$ Detailed_Output
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     An E-kernel must be loaded and a handle value for
C     it available.
C
C$ Exceptions
C
C     If an incorrect HANDLE or SEGNO is provided, this
C     routine will crash in the calling tree of routines
C     in this subroutine.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     CALL EKOPR ( 'plate.kernel', HANDLE )
C     DO I = 1, 10
C        CALL SGNOTE ( HANDLE, I )
C     END DO
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 13-SEPT-2000 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     E-kernel
C
C-&
 
 
 
      INCLUDE               'ekcnamsz.inc'
      INCLUDE               'ektnamsz.inc'
 
      INTEGER               NCOLS
      PARAMETER           ( NCOLS = 100 )
 
      INTEGER               NROWS
      INTEGER               NCOLZ
      INTEGER               SEGNO
      INTEGER               HANDLE
      INTEGER               SIZES    ( NCOLS )
      INTEGER               STRLNS   ( NCOLS )
 
      LOGICAL               INDEXD   ( NCOLS )
      LOGICAL               NULLOK   ( NCOLS )
 
      CHARACTER*(1)         FIRCHR
      CHARACTER*(20)        NUMSTR
      CHARACTER*(80)        OUTMSG
      CHARACTER*(TNAMSZ)    TABNAM
      CHARACTER*(16)        DTYPES   ( NCOLS )
      CHARACTER*(CNAMSZ)    CNAMES   ( NCOLS )
 
 
      CALL CHKIN ( 'SGNOTE' )
 
C
C     Convert segment value to an English phrase.
C
 
      CALL INTTXT ( SEGNO,  NUMSTR )
      CALL LCASE  ( NUMSTR, NUMSTR )
      FIRCHR = NUMSTR(1:1)
      CALL UCASE  ( FIRCHR, FIRCHR )
      NUMSTR(1:1) = FIRCHR
 
C
C     Obtain the segment name.
C
 
      CALL EKSSUM (  HANDLE,  SEGNO,   TABNAM,  NROWS,
     .               NCOLZ,   CNAMES,  DTYPES,  SIZES,
     .               STRLNS,  INDEXD,  NULLOK           )
 
C
C     Create the output message.
C
 
      CALL REPMC ( 'Reading Segment #: #', '#', NUMSTR, OUTMSG )
      CALL REPMC ( OUTMSG,                 '#', TABNAM, OUTMSG )
 
C      CALL TOSTDO ( OUTMSG )
 
      CALL CHKOUT ( 'SGNOTE' )
 
      RETURN
      END
