C$Procedure  SUBTRI  ( subdivide a triangle )
 
      SUBROUTINE SUBTRI ( XYZ, NDIV, NSUBS, SUBXYZ, SUBCEN )
 
C$ Abstract
C
C     Subdivide the triangle with vertex coordinates
C     XYZ into NDIV*NDIV similar triangles.  Return the
C     coordinates of the vertices and the centers.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NDIV
      INTEGER               NSUBS
 
      INTEGER               MAXGRD
      PARAMETER           ( MAXGRD = 10 )
 
      DOUBLE PRECISION      XYZ     ( 3, 3    )
      DOUBLE PRECISION      SUBCEN  ( 3, MAXGRD*MAXGRD )
      DOUBLE PRECISION      SUBXYZ  ( 3, 0:MAXGRD, 0:MAXGRD )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     XYZ        I   Coordinates of triangles vertices.
C     NDIV       I   Division parameter.
C     NSUBS      O   Number of subdivided triangles.
C     SUBXYZ     O   Coordinates of subdivided triangle vertices.
C     SUBCEN     O   Coordinates of subdivided triangle centers.
C
C$ Detailed_Input
C
C     XYZ        Coordinates of triangles vertices.
C
C     NDIV       Division parameter.
C
C$ Detailed_Output
C
C     NSUBS      Number of output triangles resulting from subdivision.
C
C     SUBXYZ     Coordinates of output triangle vertices.
C
C     SUBCEN     Coordinates of output triangle centers.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     subdivide a triangle
C
C-&
 
      INTEGER               I
      INTEGER               J
      INTEGER               M
 
      LOGICAL               RETURN
 
      DOUBLE PRECISION      A3RD
      DOUBLE PRECISION      FRAC
      DOUBLE PRECISION      A       ( 3 )
      DOUBLE PRECISION      B       ( 3 )
      DOUBLE PRECISION      C       ( 3 )
      DOUBLE PRECISION      X       ( 3 )
      DOUBLE PRECISION      Y       ( 3 )
      DOUBLE PRECISION      XSUB    ( 3 )
      DOUBLE PRECISION      YSUB    ( 3 )
      DOUBLE PRECISION      ACENT   ( 3 )
      DOUBLE PRECISION      BCENT   ( 3 )
      DOUBLE PRECISION      APOINT  ( 3 )
      DOUBLE PRECISION      BPOINT  ( 3 )
      DOUBLE PRECISION      TEMP    ( 3 )
 
 
C
C     Standard SPICELIB error handling.
C
 
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'SUBTRI' )
 
 
C
C     Initialize some constants.
C
 
      A3RD = 0.333333333333333D0
      FRAC = 1.D0 / DBLE( NDIV )
 
C
C     Obtain the vectors from vertex A to vertices B and C.
C
 
      CALL VEQU ( XYZ(1,1), A )
      CALL VEQU ( XYZ(1,2), B )
      CALL VEQU ( XYZ(1,3), C )
 
      CALL VSUB ( B, A, X )
      CALL VSUB ( C, A, Y )
 
      CALL VSCL ( FRAC, X, XSUB )
      CALL VSCL ( FRAC, Y, YSUB )
 
C
C     Determine the subdivided triangle vertex coordinates
C     recursively.
C
 
      CALL VEQU ( A, SUBXYZ(1,0,0) )
 
      DO J = 1, NDIV
         CALL VADD ( SUBXYZ(1,0,J-1), YSUB, SUBXYZ(1,0,J) )
      END DO
 
      DO J = 0, NDIV
         DO I = 1, NDIV-J
            CALL VADD ( SUBXYZ(1,I-1,J), XSUB, SUBXYZ(1,I,J) )
         END DO
      END DO
 
C
C     Determine the relative vector from the first subdivided
C     triangle to the two basic centers.
C
 
      CALL VADD ( SUBXYZ(1,0,0), SUBXYZ(1,1,0), TEMP )
      CALL VADD ( TEMP,          SUBXYZ(1,0,1), TEMP )
      CALL VSCL ( A3RD, TEMP, ACENT )
 
      CALL VADD ( SUBXYZ(1,1,0), SUBXYZ(1,1,1), TEMP )
      CALL VADD ( TEMP,          SUBXYZ(1,0,1), TEMP )
      CALL VSCL ( A3RD, TEMP, BCENT )
 
      CALL VSUB ( ACENT, SUBXYZ(1,0,0), APOINT )
      CALL VSUB ( BCENT, SUBXYZ(1,0,0), BPOINT )
 
C
C     Determine the subdivided triangle vertex centers recursively.
C
 
      M     = NDIV-1
      NSUBS = 0
 
      DO J = 0, M
         DO I = 0, M-J
            CALL VADD ( SUBXYZ(1,I,J), APOINT, TEMP )
            NSUBS = NSUBS + 1
            CALL VEQU ( TEMP, SUBCEN(1,NSUBS) )
            IF ( ( I .LT. M-J ) .AND. ( J .LT. M ) ) THEN
               CALL VADD ( SUBXYZ(1,I,J), BPOINT, TEMP )
               NSUBS = NSUBS + 1
               CALL VEQU ( TEMP, SUBCEN(1,NSUBS) )
            END IF
         END DO
      END DO
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'SUBTRI' )
 
 
      RETURN
      END
