C$Procedure  TRIDIV  ( store or get triangle division parameter )
 
      INTEGER FUNCTION TRIDIV ( VALUE )
 
C$ Abstract
C
C     Set and store the "triangle division scale" flag.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               VALUE
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VALUE      I   Triangle division parameter.
C
C$ Detailed_Input
C
C     VALUE      Triangle division parameter.  See Detailed_Output
C                for possible values and their effects.
C
C$ Detailed_Output
C
C     TRIDIV     If VALUE = -1, resets and returns the default value,
C                10.
C                If VALUE = 0, return the currently stored value.
C                If VALUE >=1, set and return VALUE.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 26-AUG-2002 (BVS)
C
C        Replaced WRITE with normal error reporting calls.
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     
C
C-&
 
      LOGICAL               RETURN
 
      INTEGER               NDIV
      INTEGER               DEFAULT
 
      SAVE  DEFAULT
      SAVE  NDIV
 
      DATA  DEFAULT  / 10 /
      DATA  NDIV     / 10 /
 
 
      TRIDIV = NDIV
 
C
C     Standard SPICELIB error handling.
C
 
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'TRIDIV' )
 
 
      IF ( VALUE .EQ. -1 ) THEN
         NDIV   = DEFAULT
         TRIDIV = NDIV
      ELSE IF ( VALUE .EQ. 0 ) THEN
         TRIDIV = NDIV
      ELSE IF ( VALUE .GE. 1 ) THEN
         NDIV   = VALUE
         TRIDIV = NDIV
      ELSE IF ( VALUE .LT. -1) THEN
         CALL SETMSG ( 'VALUE has illegal value = #.' )
         CALL ERRINT ( '#', VALUE                     )
         CALL SIGERR ( 'SPICE(ILLEGALVALUE)'          )
         CALL CHKOUT ( 'TRIDIV'                       )
         RETURN
      END IF
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'TRIDIV' )
 
 
      RETURN
      END
