C$Procedure   TRIPUP   ( identify points above plate's horizon )
 
      SUBROUTINE TRIPUP ( AVID,  BVID,   ACENT, ANORM, BVERT,
     .                    NVIS,  VISLST, ABOVE                )
 
C$ Abstract
C
C     Identify points that lie above the plane (horizon) of a plate.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT              NONE

      INTEGER               AVID      ( 3 )
      INTEGER               BVID      ( 3 )
      DOUBLE PRECISION      ACENT     ( 3 )
      DOUBLE PRECISION      ANORM     ( 3 )
      DOUBLE PRECISION      BVERT     ( 3, 3 )
      INTEGER               NVIS
      INTEGER               VISLST    ( 3 ) 
      LOGICAL               ABOVE     ( 3 )
 
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVID       I   List of plate-A's vertex IDs.
C     BVIS       I   List of plate-B's vertex IDs.
C     ACENT      I   Body-fixed coordinates of plate-A's center.
C     ANORM      I   Body-fixed components of plate-A's normal vector.
C     BVERT      I   List of body-fixed coordinates of plate-B's
C                    vertices.
C     NVIS       O   Number of plate-B vertices visible from plate-A.
C     VISLST     O   List of plate-B IDs visible from plate-A.
C     ABOVE      O   .TRUE. if a plate-B vertex is visible from plate-A,
C                    .FALSE. if not.
C
C$ Detailed_Input
C
C     AVID       List of plate-A's vertex IDs.
C     BVIS       List of plate-B's vertex IDs.
C     ACENT      Body-fixed coordinates of plate-A's center.
C     ANORM      Body-fixed components of plate-A's normal vector.
C     BVERT      List of body-fixed coordinates of plate-B's
C                vertices.
C
C$ Detailed_Output
C
C     NVIS       Number of plate-B vertices above plate-A's horizon.
C     VISLST     List of plate-B vertices above plate-A's horizon.
C     ABOVE      .TRUE. if a plate-B vertex is visible from plate-A,
C                .FALSE. if not.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     TBD
C
C$ Examples
C
C     TBD
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 22-MAR-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     plate
C
C-&

      LOGICAL               INLIST
 
      INTEGER               I
      INTEGER               PINHFS
 
 
      NVIS   = 0
 
      DO I = 1, 3
 
         ABOVE(I) = .FALSE.
 
 
         IF ( .NOT. INLIST( 3, AVID, BVID(I)) ) THEN
 
 
            IF ( PINHFS( BVERT(1,I), ACENT, ANORM ) .EQ. 1 ) THEN
               NVIS         = NVIS + 1
               VISLST(NVIS) = BVID(I)
               ABOVE(I)     = .TRUE.
            END IF
 
         END IF
 
      END DO
 
      RETURN
      END
