C$Procedure   TRITST  (is at least one voxel of B visible from A? )

      LOGICAL FUNCTION TRITST ( AVID, BVID, ACENT, ANORM, BVERT,
     .                          NVIS, VISLST )

C$ Abstract
C
C     Returns true if at least one vertex of plate B is visible from
C     plate A.  Also returns a list of plate-B vertices which are
C     visible from plate-A.
C
C$ Copyright
C
C     Copyright (2002), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               AVID      ( 3 )
      INTEGER               BVID      ( 3 )
      DOUBLE PRECISION      ACENT     ( 3 )
      DOUBLE PRECISION      ANORM     ( 3 )
      DOUBLE PRECISION      BVERT     ( 3, 3 )
      INTEGER               NVIS
      INTEGER               VISLST    ( * )

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVID       I   Plate A vertex IDs
C     BVID       I   Plate B vertex IDs
C     ACENT      I   Plate A center coordinates
C     ANORM      I   Plate A normal vector
C     BVERT      I   Plate B vertex coordinates
C     NVIS       O   Number of B vertexes visible from A 
C     VISLST     O   List of B vertexes visible from A
C
C     The function returns .TRUE. if at least one vertex of plate B is
C     visible from plate A.
C
C$ Detailed_Input
C
C     See Brief_I/O.
C
C$ Detailed_Output
C
C     See Brief_I/O.
C
C     The function returns .TRUE. if at least one vertex of plate B is
C     visible from plate A.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof     (JPL)
C     B.V. Semenov   (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 27-AUG-2002 (BVS)(JAB)
C
C-&
 
C$ Index_Entries
C
C     check if vertecies of one plate are visible from another
C
C-&


C
C     Function declarations.
C
      LOGICAL               INLIST
      INTEGER               PINHFS
 
C
C     Local variables.
C
      INTEGER               I

 
      TRITST = .FALSE.
      NVIS   = 0
 
      DO I = 1, 3
 
         IF ( .NOT. INLIST( 3, AVID, BVID(I) ) ) THEN
 
            IF ( PINHFS( BVERT(1,I), ACENT, ANORM ) .EQ. 1 ) THEN
               TRITST = .TRUE.
               NVIS = NVIS + 1
               VISLST(NVIS) = BVID(I)
            END IF
 
         END IF
 
      END DO
 
      RETURN
      END
