C$Procedure  TRIVOX  ( list plates along rays  )
 
      SUBROUTINE TRIVOX ( PLDEX, RAYDIR, NPLOUT, PLOUT )
 
C$ Abstract
C
C     Determine a list of plate IDs that might be intersected
C     by parallel rays from selected points on plate PLDEX to
C     a target.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATES  OCCLUSION
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               PLDEX
      INTEGER               NPLOUT
      INTEGER               PLOUT    ( * )
 
      DOUBLE PRECISION      RAYDIR   ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C
C     PLDEX      I   Plate index.
C     RAYDIR     I   Ray direction to target from plate.
C     NPLOUT     O   Number of plates found in voxels along all rays.
C     PLOUT      O   List of plate IDs found in voxels along all rays.
C
C$ Detailed_Input
C
C     PLDEX      Plate index.
C
C     RAYDIR     Ray direction to target from plate.
C
C$ Detailed_Output
C
C     NPLOUT     Number of plates found in voxels along all rays.
C
C     PLOUT      List of plate IDs found in volels along all rays.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     generate list of plates along rays
C
C-&
 
      INCLUDE               'pltmax.inc'
 
 
C
C     Local variables.
C
 
      INTEGER               MAXGRD
      PARAMETER           ( MAXGRD = 200 )
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               J
      INTEGER               K
      INTEGER               NDIV
      INTEGER               NSHOOT
      INTEGER               NPLATE
      INTEGER               IVDEX
      INTEGER               NVXOUT
      INTEGER               NVOX     ( 3 )
      INTEGER               VOXLST   ( MAXPLT )
      INTEGER               PLIST    ( MAXPLT )
      INTEGER               PNTRS    ( MAXPLT )
 
      DOUBLE PRECISION      VOXSIZ
      DOUBLE PRECISION      LNGSID
      DOUBLE PRECISION      BIGGER
      DOUBLE PRECISION      VOXORI   ( 3 )
      DOUBLE PRECISION      VGXYZ    ( 3 )
      DOUBLE PRECISION      POINTS   ( 3, 3 )
      DOUBLE PRECISION      START    ( 3, MAXGRD )
      DOUBLE PRECISION      GRDXYZ   ( 3, MAXGRD )
 
C
C     Standard SPICELIB error handling.
C
 
      IF ( RETURN () ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'TRIVOX' )
 
 
C
C     Get the coordinates of the plate's vertices.
C
      CALL NTHPLV ( PLDEX, POINTS )
 
C
C     Get the size of a voxel.
C
      CALL VOXDIM ( NVOX, VOXSIZ, VOXORI)
 
C
C     Get the length of the longest side of the plate.
C
      CALL NTHSID ( PLDEX, LNGSID )
 
C
C     How many rays are needed?
C
      BIGGER = LNGSID / VOXSIZ
 
C
C     Start rays from plate corners, if plate is small enough.
C
      IF ( BIGGER .LT. 1.D0  ) THEN
         DO I = 1, 3
            CALL VEQU ( POINTS(1,I), START(1,I) )
         END DO
         NSHOOT = 3
 
C
C     Start rays from corners and plate center, if required.
C
      ELSE IF ( BIGGER .LT. 2.D0 ) THEN
         DO I = 1, 3
            CALL VEQU ( POINTS(1,I), START(1,I) )
         END DO
         NSHOOT = 4
         CALL NTHPLC ( PLDEX, START(1,NSHOOT) )
 
C
C     If triangle is really large, generate additional ray
C     starting points in its interior in addition to the corners.
C
      ELSE IF ( BIGGER .GE. 2.D0 ) THEN
         NDIV = INT(BIGGER)
         CALL SUBTRI ( POINTS, NDIV, NSHOOT, GRDXYZ, START )
         DO I = 1, 3
            CALL VEQU ( POINTS(1,I), START(1,I+NSHOOT) )
         END DO
         NSHOOT = NSHOOT + 3
      END IF
 
C
C     Shoot rays and accumulate plates.
C
      CALL INILST ( MAXPLT, PNTRS, IVDEX )
 
      DO I = 1, NSHOOT
 
C
C        Convert starting point to voxel grid coordinates.
C
         CALL TOGRID ( START(1,I), VOXORI, VOXSIZ, VGXYZ )
 
C
C        Get voxels along a ray.
C
         CALL XDDA ( VGXYZ, RAYDIR, NVOX, NVXOUT, VOXLST )
 
C
C        Obtain the plates in each voxel.
C
         DO J = 1, NVXOUT
 
            CALL VOXPLT ( VOXLST(J), NPLATE, PLIST )
 
C
C           Store plate IDs in a list.
C
            DO K = 1, NPLATE
 
               IF ( PLIST(K) .NE. PLDEX ) THEN
                  CALL ADDLST ( PLIST(K), IVDEX, PNTRS, PLOUT )
               END IF
 
            END DO
 
         END DO
 
      END DO
 
      NPLOUT = IVDEX
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'TRIVOX' )
 
      RETURN
      END
