C$Procedure      V2LCOM ( Vector linear combination, 2 dimensions )
 
      SUBROUTINE V2LCOM ( A, V1, B, V2, SUM )
 
C$ Abstract
C
C      Compute a vector linear combination of two double precision,
C      2-dimensional vectors.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION   A
      DOUBLE PRECISION   V1  ( 2 )
      DOUBLE PRECISION   B
      DOUBLE PRECISION   V2  ( 2 )
      DOUBLE PRECISION   SUM ( 2 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C      A          I   Coefficient of V1
C      V1         I   Vector in 2-space
C      B          I   Coefficient of V2
C      V2         I   Vector in 2-space
C      SUM        O   Linear Vector Combination A*V1 + B*V2
C
C$ Detailed_Input
C
C      A     This double precision variable multiplies V1.
C      V1    This is an arbitrary, double precision 2-dimensional
C            vector.
C      B     This double precision variable multiplies V2.
C      V2    This is an arbitrary, double precision 2-dimensional
C            vector.
C
C$ Detailed_Output
C
C      SUM   is an arbitrary, double precision 2-dimensional vector
C            which contains the linear combination A*V1 + B*V2.
C
C$ Parameters
C
C      None.
C
C$ Particulars
C
C      For each index from 1 to 2, this routine implements in FORTRAN
C      code the expression:
C
C      SUM(I) = A*V1(I) + B*V2(I)
C
C      No error checking is performed to guard against numeric overflow.
C
C$ Examples
C
C      To generate a sequence of points on an ellipse with major
C      and minor axis vectors MAJOR and MINOR, one could use the
C      following code fragment
C
C            STEP = TWOPI()/ N
C            ANG  = 0.0D0
C
C            DO I = 0,N
C
C               CALL V2LCOM ( DCOS(ANG),MAJOR,  DSIN(ANG),MINOR,  POINT)
C
C               do something with the ellipse point just constructed
C
C               ANG = ANG + STEP
C
C            END DO
C
C
C$ Restrictions
C
C      No error checking is performed to guard against numeric overflow
C      or underflow.  The user is responsible for insuring that the
C      input values are reasonable.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C      None
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 24-OCT-1996 (WLT)
C
C-&
 
C$ Index_Entries
C
C     linear combination of two 2-dimensional vectors
C
C-&
 
      SUM(1) = A*V1(1) + B*V2(1)
      SUM(2) = A*V1(2) + B*V2(2)
 
      RETURN
      END
