C$Procedure      VDOT2 ( Vector dot product of 2-vectors )
 
      DOUBLE PRECISION FUNCTION VDOT2 ( V1, V2 )
 
C$ Abstract
C
C     This routine returns the vector dot product for  a pair
C     of 2-vectors.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      IMPLICIT NONE
      DOUBLE PRECISION      V1 ( 2 )
      DOUBLE PRECISION      V2 ( 2 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     V1         I   Any 2-vector
C     V2         I   Any 2-vector
C
C     The function returns the vector dot product of V1 and V2
C
C$ Detailed_Input
C
C     V1         are any pair of 2-dimensional double precision
C     V2         vectors.
C
C$ Detailed_Output
C
C     The function returns the value of the dot product of V1 and V2.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine simply serves as a macro for the computation
C
C         V1(1)*V2(1) + V1(2)*V2(2)
C
C     It makes writing code simpler and reduces the chance for
C     index errors.
C
C$ Examples
C
C     Suppose you'd like to determine the component of one vector
C     that is parallel to another.  Using VDOT2 together with
C     the routine VSCL2, you can easily make this computation.
C
C     Let V1 be the vector to be projected on another vector V2.
C     (We assume V2 is non-zero).  The projection computed as
C     follows.
C
C         CALL VSCL2 ( VDOT2(V1,V2)/VDOT2(V2,V2), V2, VPROJ )
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 24-OCT-1996 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     Compute the dot product of two 2-dimensional vectors
C
C-&
 
      VDOT2 = V1(1)*V2(1) + V1(2)*V2(2)
      RETURN
      END
