C$Procedure      VHAT2 ( "V-Hat", unit vector along V, 2 dimensions )
 
      SUBROUTINE VHAT2 ( V1, VOUT )
 
C$ Abstract
C
C      Find the unit vector along a double precision 2-dimensional
C      vector.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION   V1   ( 2 )
      DOUBLE PRECISION   VOUT ( 2 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     Vector to be normalized.
C       VOUT      O     Unit vector V1 / |V1|.
C                       If V1 = 0, VOUT will also be zero.
C                       VOUT can overwrite V1.
C
C$ Detailed_Input
C
C      V1      This is any double precision, 2-dimensional vector.  If
C              this vector is the zero vector, this routine will detect
C              it, and will not attempt to divide by zero.
C
C$ Detailed_Output
C
C      VOUT    VOUT contains the unit vector in the direction of V1. If
C              V1 represents the zero vector, then VOUT will also be the
C              zero vector.  VOUT may overwrite V1.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      VHAT2 determines the magnitude of V1 and then divides each
C      component of V1 by the magnitude.  This process is highly stable
C      over the whole range of 2-dimensional vectors.
C
C$ Examples
C
C      The following table shows how selected V1 implies VOUT.
C
C      V1                    VOUT
C      ------------------    ------------------
C      (5, 12)               (5/13, 12/13)
C
C
C$ Restrictions
C
C      There is no known case whereby floating point overflow may occur.
C      Thus, no error recovery or reporting scheme is incorporated
C      into this subroutine.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber      (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 24-OCT-1996 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     unitize a 2-dimensional vector
C
C-&
C
C     SPICELIB Functions
C
      DOUBLE PRECISION VNORM2
C
C     Local Variables
C
      DOUBLE PRECISION VMAG
C
C  Obtain the magnitude of V1
C
      VMAG = VNORM2(V1)
C
C   If VMAG is nonzero, then normalize.  Note that this process is
C   numerically stable: overflow could only happen if VMAG were small,
C   but this could only happen if each component of V1 were small.
C   In fact, the magnitude of any vector is never less than the
C   magnitude of any component.
C
      IF (VMAG.GT.0.D0) THEN
         VOUT(1) = V1(1) / VMAG
         VOUT(2) = V1(2) / VMAG
      ELSE
         VOUT(1) = 0.D0
         VOUT(2) = 0.D0
      END IF
 
      RETURN
      END
