C$Procedure      VMINU2 ( Minus V, "-V", 2 dimensions )
 
      SUBROUTINE VMINU2 ( V1, VOUT )
 
C$ Abstract
C
C      Negate a double precision 2-dimensional vector.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION      V1   ( 2 )
      DOUBLE PRECISION      VOUT ( 2 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     Vector to be negated.
C       VOUT      O     Negated vector -V1. VOUT can overwrite V1.
C
C
C$ Detailed_Input
C
C      V1      This may be any 2-dimensional, double precision vector.
C
C$ Detailed_Output
C
C      VOUT    This will be the negation (additive inverse) of V1.  It
C              is a 2-dimensional, double precision vector.  VOUT may
C              overwrite V1.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      VMINU2 implements (by components) the expression VMINU2 = -V1.
C      No error checking is performed since overflow can occur ONLY if
C      the dynamic range of positive floating point numbers is not the
C      same size as the dynamic range of negative floating point
C      numbers AND at least one component of V1 falls outside the
C      common range.  The likelihood of this occurring is so small as to
C      be of no concern.
C
C$ Examples
C
C      The following table shows the output VOUT as a function of the
C      the input V1 from the subroutine VMINU2.
C
C      V1                     VOUT
C      -------------------------------------------------------
C      (1D0, -2D0 )       (-1D0, 2D0 )
C      (0D0,  0D0 )       ( 0D0, 0D0 )
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 24-OCT-1996 (WLT)
C
C-&
 
C$ Index_Entries
C
C     negate a 2-dimensional vector
C
C-&
 
      VOUT(1) = -V1(1)
      VOUT(2) = -V1(2)
 
      RETURN
      END
