C$Procedure      VNORM2 ( Vector norm, 2 dimensions )
 
      DOUBLE PRECISION FUNCTION VNORM2 ( V1 )
 
C$ Abstract
C
C      Compute the magnitude of a double precision, 2-dimensional
C      vector.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION  V1 ( 2 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     Vector whose magnitude is to be found.
C
C$ Detailed_Input
C
C      V1      This may be any 2-dimensional, double precision vector.
C
C$ Detailed_Output
C
C      VNORM2 is the magnitude of V1 calculated in a numerically stable
C      way.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      VNORM2 computes the value of DSQRT( V1(1)**2 + V(2)**2 ) via
C      a method that minimizes the chance of overflow or underflow
C      of the computation.
C
C$ Examples
C
C      The following table show the correlation between various input
C      vectors V1 and VNORM2:
C
C      V1                               VNORM2
C      -----------------------------------------------------------------
C      (5.D0,   12.D0     )             13.D0
C      (3.D-17,  4.0D-17  )              5.D-17
C
C$ Restrictions
C
C      None.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 24-OCT-1996 (WLT)
C
C-&
 
C$ Index_Entries
C
C     norm of 2-dimensional vector
C
C-&
 
      DOUBLE PRECISION      V1MAX
      DOUBLE PRECISION      X
      DOUBLE PRECISION      Y
C
C  Determine the maximum component of the vector.
C
      X     = DABS(V1(1))
      Y     = DABS(V1(2))
 
      V1MAX = MAX (X,Y)
C
C  If the vector is zero, return zero; otherwise normalize first.
C  Normalizing helps in the cases where squaring would cause overflow
C  or underflow.  In the cases where such is not a problem it not worth
C  it to optimize further.
C
      IF (V1MAX.EQ.0.D0) THEN
         VNORM2 = 0.D0
      ELSE IF ( V1MAX .EQ. X ) THEN
         VNORM2 = V1MAX * DSQRT (  1.0D0  +  (Y/V1MAX)**2  )
      ELSE
         VNORM2 = V1MAX * DSQRT (  1.0D0  +  (X/V1MAX)**2  )
      END IF
 
      RETURN
      END
