C$Procedure VOX2ID (Return voxel index from coords)
 
      INTEGER FUNCTION VOX2ID ( VIXYZ, NVOX )
 
C$ Abstract
C
C     Given a voxel's grid coordinates and the voxel grid
C     dimensions, return the voxel's index.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     VOXEL
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NVOX   ( 3 )
      INTEGER               VIXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VIXYZ      I   Voxel's grid coordinates stored in a
C                    three-dimensional vector.
C     NVOX       I   Number of voxels in each coordinate direction.
C
C     The function returns the voxel index.
C
C$ Detailed_Input
C
C     VIXYZ      An integer 3-vector storing the voxel grid coordinates
C                for the point of interest.
C
C     NVOX       An integer 3-vector defining the span of
C                the cubic voxels for each coordinate axis. 
C
C                   NVOX(1) = NINT( X         - X         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(2) = NINT( Y         - Y         )
C                                    Vox_max     Vmin_min
C
C                   NVOX(3) = NINT( Z         - Z         )
C                                    Vox_max     Vmin_min
C
C                Where:
C
C                      X          Y          Z
C                       Vox_max    Vox_max    Vox_max
C
C                represent the maximum values of all voxel
C                space coordinates along each axis, and:
C
C                      X          Y          Z
C                       Vox_min    Vox_min    Vox_min
C
C                represent the minimum values of all voxel
C                space coordinates along each axis. 
C
C                NINT being the FORTRAN "nearest integer" function.
C
C$ Detailed_Output
C
C     The function returns the value of the voxel index.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICE Version 1.1.0, 23-SEP-2004 (EDW)
C
C        Recast equation to improve runtime performance.
C        Edited comments for clarity.
C
C        Subroutine renamed from GETXYZ.
C
C-    Plate Library Version 1.0.1, 19-FEB-2000 (JAB)
C
C        Removed SAVED variables.
C
C-    Plate Library Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     given a voxel's coordinates return the voxel index
C
C-&

C
C     Convert from voxel coordinates to voxel index. A more
C     readable form for the following function:
C
C      NX     = NVOX(1)
C      NY     = NVOX(2)
C      NXNY   = NX * NY
C      NXNY2  = NX + NXNY
C
C      VOX2ID = VIXYZ(1) + VIXYZ(2)*NX + VIXYZ(3)*NXNY - NXNY2
C
C     Expressing the function in this format improves runtime
C     performance as per Horner's Rule.
C
      VOX2ID = VIXYZ(1) + NVOX(1)*( (VIXYZ(2) + VIXYZ(3)*NVOX(2))
     .                                          - (1 + NVOX(2)) )

 
      RETURN
      END
