C$Procedure  VOXPAD  ( extend to integral voxel )
 
      DOUBLE PRECISION FUNCTION  VOXPAD ( PADINT, VAL )
  
C$ Abstract
C
C     Return the distance required in voxel grid units to extend 
C     or reduce the voxel grid by VAL from PADINT.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     VOXEL
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               PADINT
      DOUBLE PRECISION      VAL
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PADINT     I   Number of additional voxels to pad out to.
C     VAL        I   Current value.
C
C     The function returns the extension distance required
C     to widen the voxel grid the desired amount.
C
C$ Detailed_Input
C
C
C$ Detailed_Output
C
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.1.0, 30-SEP-2004 (EDW)
C
C        Initialized VOXPAD to 0.D0 to handle
C        return on error.
C
C-    SPICELIB Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     pad voxel grid with additional voxels
C
C-&

      LOGICAL               RETURN

C
C     Set VOXPAD to 0 prior to processing.
C
      VOXPAD = 0.D0

C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'VOXPAD' )

C
C     The code.
C
      IF ( PADINT .LT. 0 ) THEN
 
         IF ( VAL .LT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT )
         ELSE IF ( VAL .GT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT ) - 1.D0
         ELSE
            VOXPAD = DBLE( PADINT )
         END IF
 
      ELSE IF ( PADINT .GT. 0 ) THEN
 
         IF ( VAL .GT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT )
         ELSE IF ( VAL .LT. 0.D0 ) THEN
            VOXPAD = DNINT( VAL ) + DBLE( PADINT ) + 1.D0
         ELSE
            VOXPAD = DBLE( PADINT )
         END IF
 
      ELSE
 
         CALL SETMSG ( 'Padding direction not given.' )
         CALL SIGERR ( 'SPICE(NOPADDINGDIR)'          )
         CALL CHKOUT ( 'VOXPAD'                       )
         RETURN
 
      END IF
 
C
C     Standard SPICELIB error handling.
C
      CALL CHKOUT ( 'VOXPAD' )
 
      RETURN
      END
