C$Procedure      VSUB2 ( Vector subtraction, 2 dimensions )
 
      SUBROUTINE VSUB2 ( V1, V2, VOUT )
 
C$ Abstract
C
C      Compute the difference between two 2-dimensional, double
C      precision vectors.
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C      VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION  V1   ( 2 )
      DOUBLE PRECISION  V2   ( 2 )
      DOUBLE PRECISION  VOUT ( 2 )
 
C$ Brief_I/O
C
C      VARIABLE  I/O  DESCRIPTION
C      --------  ---  --------------------------------------------------
C       V1        I     First vector (minuend).
C       V2        I     Second vector (subtrahend).
C       VOUT      O     Difference vector, V1 - V2. VOUT can overwrite
C                        either V1 or V2.
C
C$ Detailed_Input
C
C      V1    This can be any 2-dimensional, double precision vector.
C
C      V2    Ditto.
C
C$ Detailed_Output
C
C      VOUT   This is a 2-dimensional, double precision vector which
C             represents the vector difference, V1 - V2.
C
C$ Parameters
C
C     None.
C
C$ Particulars
C
C      This routine simply performs subtraction between components of V1
C      and V2.  No checking is performed to determine whether floating
C      point overflow has occurred.
C
C$ Examples
C
C      The following table shows the output VOUT as a function of the
C      input V1 and V2 from the subroutine VSUB2.
C
C      V1               V2            ---> VOUT
C      -----------      ------------       --------------
C      (1.0, 2.0 )      (4.0,  5.0 )       (-3.0, -3.0 )
C      (1D-7,1D23)      (1D24, 1D23)       (1D24, 2D23 )
C
C$ Restrictions
C
C      The user is required to determine that the magnitude each
C      component of the vectors is within the appropriate range so as
C      not to cause floating point overflow.  No error recovery or
C      reporting scheme is incorporated in this subroutine.
C
C$ Exceptions
C
C      Error free.
C
C$ Files
C
C      None.
C
C$ Author_and_Institution
C
C      W.L. Taber       (JPL)
C
C$ Literature_References
C
C      None.
C
C$ Version
C
C-     SPICELIB Version 1.0.0, 24-OCT-1996 (WLT)
C
C-&
 
C$ Index_Entries
C
C     2-dimensional vector subtraction
C
C-&
 
      VOUT(1) = V1(1) - V2(1)
      VOUT(2) = V1(2) - V2(2)
 
      RETURN
      END
