C$Procedure  VZERO2    ( Is a vector the zero vector? )
 
      LOGICAL FUNCTION VZERO2 ( V )
 
C$ Abstract
C
C     Indicate whether a 2-vector is the zero vector.
C
C$ Copyright
C
C     Copyright (1996), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     MATH
C     VECTOR
C
C$ Declarations
 
      DOUBLE PRECISION      V ( 2 )
 
C$ Brief_I/O
C
C     Variable  I/O  Description
C     --------  ---  --------------------------------------------------
C     V          I   Vector to be tested.
C
C     The function returns the value .TRUE. if and only if V is the
C     zero vector.
C
C$ Detailed_Input
C
C     V              is a vector in 2-space.
C
C$ Detailed_Output
C
C     The function returns the value .TRUE. if and only if V is the
C     zero vector.
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     This function has the same truth value as the logical expression
C
C        VNORM ( V )  .EQ.  0.D0
C
C     Replacing the above expression by
C
C        VZERO2 ( V )
C
C     has several advantages:  the latter expresses the test more
C     clearly, looks better, and doesn't go through the work of scaling,
C     squaring, taking a square root, and re-scaling (all of which
C     VNORM must do) just to find out that a vector is non-zero.
C
C     A related function is VZERO2G, which accepts vectors of arbitrary
C     dimension.
C
C$ Examples
C
C     1)  When testing whether a vector is the zero vector, one
C         normally constructs tests like
C
C            IF (  VNORM ( V )  .EQ.  0.D0  ) THEN
C                        .
C                        .
C                        .
C
C
C         These can be replaced with the code
C
C            IF (  VZERO2 ( V )  ) THEN
C                        .
C                        .
C                        .
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber     (JPL)
C     I.M. Underwood (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 24-OCT-1996 (WLT)
C
C-&
 
C$ Index_Entries
C
C     test whether a 2-dimensional vector is the zero vector
C
C-&
 
 
 
C
C     `Just do it'.
C
C
      VZERO2   =       (  V(1) .EQ. 0.D0  )
     .          .AND.  (  V(2) .EQ. 0.D0  )
 
      RETURN
      END
