C$Procedure      ALDUMP ( output plate albedo data to file )
 
      SUBROUTINE ALDUMP ( NAIFID, FNAME )
 
C$ Abstract
C
C     Output plate albedo data to an ASCII file.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     PLATE MODEL
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               NAIFID
      CHARACTER*(*)         FNAME
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAIFID     I   NAIF ID of the body whose plate albedo data
C                    is to be output.
C     FNAME      I   Name of the output file.
C
C$ Detailed_Input
C
C     NAIFID     The standard NAIF ID of the body whose plate albedo
C                data is to be output to an ASCII flatfile.
C
C     FNAME      Name of the output ASCII flatfile.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If information required by this routine has not been
C        loaded prior to calling this routine, the omission will
C        be diagnosed by a routine in the call tree of this routine.
C
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C     1) DB kernel(s) must be loaded containing plate model data
C        for the body specified by the input NAIFID.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 20-AUG-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     output plate albedo data to an ASCII flatfile
C
C-&
 
 
      INCLUDE               'pltmax.inc'
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               NP
      INTEGER               NV
      INTEGER               PID
      INTEGER               PBEG
      INTEGER               PEND
      INTEGER               UNIT
      INTEGER               BODEX
      INTEGER               PBOUND   ( 2 )
      INTEGER               VBOUND   ( 2 )
 
      CHARACTER*(12)        C12
      CHARACTER*(20)        C20
 
      DOUBLE PRECISION      ALBEDO
 
 
C
C     Create a Plate Albedo flatfile from stored kernel data.
C
      IF ( RETURN() ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'ALDUMP' )
      END IF
 
C
C     Get body index from its name; obtain knowledge of
C     where the plate albedo data is stored in the
C     PLTMGR buffer.
C
      CALL BID2DX ( NAIFID, BODEX                    )
      CALL PLTBND ( BODEX,  NP,   PBOUND, NV, VBOUND )
 
C
C     Open ASCII file for writing.
C
      CALL TXTOPN ( FNAME, UNIT )
 
C
C    Write out number of plates.
C
      CALL INTSTR ( NP,  C12  )
      CALL WRITLN ( C12, UNIT )
 
C
C    Obtain and output the albedo.
C
      PBEG = PBOUND( 1 )
      PEND = PBOUND( 2 )
 
      DO I = PBEG, PEND
         CALL NTHALB ( I,      PID,  ALBEDO )
         CALL INTSTR ( PID,    C12          )
         CALL DPSTR  ( ALBEDO, 8,    C20    )
         CALL WRITLN ( C12 // C20,  UNIT    )
      END DO
 
 
      CLOSE ( UNIT )
 
      CALL CHKOUT ( 'ALDUMP' )
 
      RETURN
 
      END
