C$Procedure PLDUMP ( output plate model data to an ASCII flatfile )
C
      SUBROUTINE PLDUMP ( NAIFID, FNAME )
C
C$ Abstract
C
C     Output plate model data to an ASCII flatfile.
C
C$ Copyright
C
C     Copyright (1997), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NAIFID
      CHARACTER*(*)         FNAME
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAIFID     I   NAIF ID of the body whose plate model data is to be
C                    output.
C
C     FNAME      I   Name of the output file.
C
C
C$ Detailed_Input
C
C     NAIFID     The standard NAIF ID of the body whose plate model
C                data is to be output to an ASCII flatfile.
C
C     FNAME      Name of the output ASCII flatfile.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     See: $Restrictions.
C
C$ Exceptions
C
C     1) If information required by this routine has not been
C        loaded prior to calling this routine, the omission will
C        be diagnosed by a routine in the call tree of this routine.
C
C$ Particulars
C
C     Given a body's NAIF ID code, output the contents of the plate
C     manager for that body to a human-readable flatfile with the
C     given name.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     1) DB kernel(s) must be loaded containing plate model data
C        for the body specified by the input NAIFID.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 20-JUN-1997 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     output a plate model to an ASCII flatfile
C
C-&
 
      INCLUDE               'pltmax.inc'
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               J
      INTEGER               NP
      INTEGER               NV
      INTEGER               PID
      INTEGER               VID
      INTEGER               PBEG
      INTEGER               PEND
      INTEGER               VBEG
      INTEGER               VEND
      INTEGER               UNIT
      INTEGER               BODEX
      INTEGER               VIDOUT
      INTEGER               VLIST       ( 3 )
      INTEGER               PBOUND      ( 2 )
      INTEGER               VBOUND      ( 2 )
 
      CHARACTER*(12)        C12         ( 4 )
      CHARACTER*(20)        C20         ( 3 )
 
      DOUBLE PRECISION      VRTXYZ      ( 3 )
 
 
C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'PLDUMP' )
      END IF
 
C
C     Given a NAIF ID, determine the Plate Manager body index and
C     then obtain the indices locating that body's plates and
C     vertices in the Plate Manager's storage arrays.
C
      CALL BID2DX ( NAIFID, BODEX                    )
      CALL PLTBND ( BODEX,  NP,   PBOUND, NV, VBOUND )
 
C
C     Open ASCII file for writing.
C
      CALL TXTOPN ( FNAME, UNIT    )
 
C
C     Write out number of vertices.
C
      CALL INTSTR ( NV,     C12(1) )
      CALL WRITLN ( C12(1), UNIT   )
 
C
C     Write out vertex coordinates.
C
      VBEG = VBOUND( 1 )
      VEND = VBOUND( 2 )
 
      DO I = VBEG, VEND
         CALL NTHVRT ( I,   VID,  VRTXYZ )
         CALL INTSTR ( VID, C12(1)       )
         DO J = 1, 3
            CALL DPSTR  ( VRTXYZ(J), 8, C20(J) )
         END DO
         CALL WRITLN ( C12(1)
     .   //            C20(1)
     .   //            C20(2)
     .   //            C20(3), UNIT )
      END DO
 
C
C     Write out number of plates.
C
      CALL INTSTR ( NP,     C12(1) )
      CALL WRITLN ( C12(1), UNIT   )
 
C
C     Write out vertex list.
C
 
      PBEG = PBOUND( 1 )
      PEND = PBOUND( 2 )
 
      DO I = PBEG, PEND
         CALL NTHPVL  ( I,   PID,  VLIST )
         CALL INTSTR  ( PID, C12(1)      )
         DO J = 1, 3
            CALL NTHVRI  ( VLIST(J), BODEX, VIDOUT )             
            CALL INTSTR  ( VIDOUT,   C12(J+1)      )
         END DO
         CALL WRITLN ( C12(1)
     .   //            C12(2)
     .   //            C12(3)
     .   //            C12(4), UNIT )
      END DO
 
      CLOSE ( UNIT )
 
      CALL CHKOUT ( 'PLDUMP' )
 
      RETURN
 
      END
